% Auto-generated chapter 9 for bukhari
% Hadiths in this chapter: 77

\hadithdefcmd{bukhari}{522}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالَ قَرَأْتُ عَلَى مَالِكٍ عَنِ ابْنِ شِهَابٍ، أَنَّ عُمَرَ بْنَ عَبْدِ الْعَزِيزِ، أَخَّرَ الصَّلاَةَ يَوْمًا، فَدَخَلَ عَلَيْهِ عُرْوَةُ بْنُ الزُّبَيْرِ، فَأَخْبَرَهُ أَنَّ الْمُغِيرَةَ بْنَ شُعْبَةَ أَخَّرَ الصَّلاَةَ يَوْمًا وَهْوَ بِالْعِرَاقِ، فَدَخَلَ عَلَيْهِ أَبُو مَسْعُودٍ الأَنْصَارِيُّ فَقَالَ مَا هَذَا يَا مُغِيرَةُ أَلَيْسَ قَدْ عَلِمْتَ أَنَّ جِبْرِيلَ نَزَلَ فَصَلَّى، فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ صَلَّى فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ قَالَ ‏ "‏ بِهَذَا أُمِرْتُ ‏"‏‏.‏ فَقَالَ عُمَرُ لِعُرْوَةَ اعْلَمْ مَا تُحَدِّثُ أَوَإِنَّ جِبْرِيلَ هُوَ أَقَامَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم وَقْتَ الصَّلاَةِ‏.‏ قَالَ عُرْوَةُ كَذَلِكَ كَانَ بَشِيرُ بْنُ أَبِي مَسْعُودٍ يُحَدِّثُ عَنْ أَبِيهِ‏.‏ قَالَ عُرْوَةُ وَلَقَدْ حَدَّثَتْنِي عَائِشَةُ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يُصَلِّي الْعَصْرَ، وَالشَّمْسُ فِي حُجْرَتِهَا قَبْلَ أَنْ تَظْهَرَ‏.‏\hadithno{522}\hadithtrans{Narrated Ibn Shihab:Once `Umar bin `Abdul `Aziz delayed the prayer and `Urwa bin Az-Zubair went to him and said, "Once in 'Iraq, Al-Mughira bin Shu`ba delayed his prayers and Abi Mas`ud Al-Ansari went to him and said, 'O Mughira! What is this? Don't you know that once Gabriel came and offered the prayer (Fajr prayer) and Allah's Messenger (ﷺ) prayed too, then he prayed again (Zuhr prayer) and so did Allah's Apostle and again he prayed (`Asr prayers and Allah's Messenger (ﷺ) did the same; again he prayed (Maghrib-prayer) and so did Allah's Messenger (ﷺ) and again prayed (`Isha prayer) and so did Allah's Apostle and (Gabriel) said, 'I was ordered to do so (to demonstrate the prayers prescribed to you)?'" `Umar (bin `Abdul `Aziz) said to `Urwa, "Be sure of what you Say. Did Gabriel lead Allah's Messenger (ﷺ) at the stated times of the prayers?" `Urwa replied, "Bashir bin Abi Mas`ud narrated like this on the authority of his father." `Urwa added, "Aisha told me that Allah's Messenger (ﷺ) used to pray `Asr prayer when the sunshine was still inside her residence (during the early time of `Asr)}}
\hadithdefcmd{bukhari}{523}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، قَالَ حَدَّثَنَا عَبَّادٌ ـ هُوَ ابْنُ عَبَّادٍ ـ عَنْ أَبِي جَمْرَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَدِمَ وَفْدُ عَبْدِ الْقَيْسِ عَلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالُوا إِنَّا مِنْ هَذَا الْحَىِّ مِنْ رَبِيعَةَ، وَلَسْنَا نَصِلُ إِلَيْكَ إِلاَّ فِي الشَّهْرِ الْحَرَامِ، فَمُرْنَا بِشَىْءٍ نَأْخُذْهُ عَنْكَ، وَنَدْعُو إِلَيْهِ مَنْ وَرَاءَنَا‏.‏ فَقَالَ ‏ "‏ آمُرُكُمْ بِأَرْبَعٍ، وَأَنْهَاكُمْ عَنْ أَرْبَعٍ الإِيمَانِ بِاللَّهِ ـ ثُمَّ فَسَّرَهَا لَهُمْ شَهَادَةُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ، وَأَنِّي رَسُولُ اللَّهِ، وَإِقَامُ الصَّلاَةِ، وَإِيتَاءُ الزَّكَاةِ، وَأَنْ تُؤَدُّوا إِلَىَّ خُمُسَ مَا غَنِمْتُمْ، وَأَنْهَى عَنِ الدُّبَّاءِ وَالْحَنْتَمِ وَالْمُقَيَّرِ وَالنَّقِيرِ ‏"‏‏.‏\hadithno{523}\hadithtrans{Narrated Ibn `Abbas:"Once a delegation of `Abdul Qais came to Allah's Messenger (ﷺ) and said, "We belong to such and such branch of the tribe of Rabi'ah and we can only come to you in the sacred months. Order us to do something good so that we may take it from you and also invite to it those whom we have left behind (at home)." So he said, "I order you to do four things and forbid you from four things: To believe in Allah" - and then he explained it to them "to testify that none has the right to be worshipped but Allah and that I am Allah's Messenger (ﷺ), to establish the prayers (at the stated times), to pay the Zakat (obligatory charity), to hand me the Khumus (fifth) if you acquire spoils of war. And I forbid from (using) Dubba, Hantam, Muqaiyyar, and Naqir (all these were utensils used for the preparation of alcoholic drinks)}}
\hadithdefcmd{bukhari}{524}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، قَالَ حَدَّثَنَا قَيْسٌ، عَنْ جَرِيرِ بْنِ عَبْدِ اللَّهِ، قَالَ بَايَعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى إِقَامِ الصَّلاَةِ، وَإِيتَاءِ الزَّكَاةِ، وَالنُّصْحِ لِكُلِّ مُسْلِمٍ‏.‏\hadithno{524}\hadithtrans{Narrated Jarir bin `Abdullah:I gave the pledge of allegiance to Allah's Messenger (ﷺ) for to offer prayers perfectly, to pay Zakat regularly, and to give good advice to every Muslim}}
\hadithdefcmd{bukhari}{525}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنِ الأَعْمَشِ، قَالَ حَدَّثَنِي شَقِيقٌ، قَالَ سَمِعْتُ حُذَيْفَةَ، قَالَ كُنَّا جُلُوسًا عِنْدَ عُمَرَ ـ رضى الله عنه ـ فَقَالَ أَيُّكُمْ يَحْفَظُ قَوْلَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي الْفِتْنَةِ قُلْتُ أَنَا، كَمَا قَالَهُ‏.‏ قَالَ إِنَّكَ عَلَيْهِ ـ أَوْ عَلَيْهَا ـ لَجَرِيءٌ‏.‏ قُلْتُ ‏ "‏ فِتْنَةُ الرَّجُلِ فِي أَهْلِهِ وَمَالِهِ وَوَلَدِهِ وَجَارِهِ تُكَفِّرُهَا الصَّلاَةُ وَالصَّوْمُ وَالصَّدَقَةُ وَالأَمْرُ وَالنَّهْىُ ‏"‏‏.‏ قَالَ لَيْسَ هَذَا أُرِيدُ، وَلَكِنِ الْفِتْنَةُ الَّتِي تَمُوجُ كَمَا يَمُوجُ الْبَحْرُ‏.‏ قَالَ لَيْسَ عَلَيْكَ مِنْهَا بَأْسٌ يَا أَمِيرَ الْمُؤْمِنِينَ، إِنَّ بَيْنَكَ وَبَيْنَهَا بَابًا مُغْلَقًا‏.‏ قَالَ أَيُكْسَرُ أَمْ يُفْتَحُ قَالَ يُكْسَرُ‏.‏ قَالَ إِذًا لاَ يُغْلَقَ أَبَدًا‏.‏ قُلْنَا أَكَانَ عُمَرُ يَعْلَمُ الْبَابَ قَالَ نَعَمْ، كَمَا أَنَّ دُونَ الْغَدِ اللَّيْلَةَ، إِنِّي حَدَّثْتُهُ بِحَدِيثٍ لَيْسَ بِالأَغَالِيطِ‏.‏ فَهِبْنَا أَنْ نَسْأَلَ حُذَيْفَةَ، فَأَمَرْنَا مَسْرُوقًا فَسَأَلَهُ فَقَالَ الْبَابُ عُمَرُ‏.‏\hadithno{525}\hadithtrans{Narrated Shaqiq:that he had heard Hudhaifa saying, "Once I was sitting with `Umar and he said, 'Who amongst you remembers the statement of Allah's Messenger (ﷺ) about the afflictions?' I said, 'I know it as the Prophet (ﷺ) had said it.' `Umar said, 'No doubt you are bold.' I said, 'The afflictions caused for a man by his wife, money, children and neighbor are expiated by his prayers, fasting, charity and by enjoining (what is good) and forbidding (what is evil).' `Umar said, 'I did not mean that but I asked about that affliction which will spread like the waves of the sea.' I (Hudhaifa) said, 'O leader of the faithful believers! You need not be afraid of it as there is a closed door between you and it.' `Umar asked, Will the door be broken or opened?' I replied, 'It will be broken.' `Umar said, 'Then it will never be closed again.' I was asked whether `Umar knew that door. I replied that he knew it as one knows that there will be night before the tomorrow morning. I narrated a Hadith that was free from any misstatement" The subnarrator added that they deputized Masruq to ask Hudhaifa (about the door). Hudhaifa said, "The door was `Umar himself}}
\hadithdefcmd{bukhari}{526}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، عَنْ سُلَيْمَانَ التَّيْمِيِّ، عَنْ أَبِي عُثْمَانَ النَّهْدِيِّ، عَنِ ابْنِ مَسْعُودٍ، أَنَّ رَجُلاً، أَصَابَ مِنَ امْرَأَةٍ قُبْلَةً، فَأَتَى النَّبِيَّ صلى الله عليه وسلم فَأَخْبَرَهُ، فَأَنْزَلَ اللَّهُ ‏\{‏أَقِمِ الصَّلاَةَ طَرَفَىِ النَّهَارِ وَزُلَفًا مِنَ اللَّيْلِ إِنَّ الْحَسَنَاتِ يُذْهِبْنَ السَّيِّئَاتِ‏\}‏‏.‏ فَقَالَ الرَّجُلُ يَا رَسُولَ اللَّهِ أَلِي هَذَا قَالَ ‏"‏ لِجَمِيعِ أُمَّتِي كُلِّهِمْ ‏"‏‏.‏\hadithno{526}\hadithtrans{Narrated Ibn Mas`ud:A man kissed a woman (unlawfully) and then went to the Prophet (ﷺ) and informed him. Allah revealed: And offer prayers perfectly At the two ends of the day And in some hours of the night (i.e. the five compulsory prayers). Verily! good deeds remove (annul) the evil deeds (small sins) (11.114). The man asked Allah's Messenger (ﷺ), "Is it for me?" He said, "It is for all my followers}}
\hadithdefcmd{bukhari}{527}{حَدَّثَنَا أَبُو الْوَلِيدِ، هِشَامُ بْنُ عَبْدِ الْمَلِكِ قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ الْوَلِيدُ بْنُ الْعَيْزَارِ أَخْبَرَنِي قَالَ سَمِعْتُ أَبَا عَمْرٍو الشَّيْبَانِيَّ، يَقُولُ حَدَّثَنَا صَاحِبُ، هَذِهِ الدَّارِ وَأَشَارَ إِلَى دَارِ عَبْدِ اللَّهِ قَالَ سَأَلْتُ النَّبِيَّ صلى الله عليه وسلم أَىُّ الْعَمَلِ أَحَبُّ إِلَى اللَّهِ قَالَ ‏"‏ الصَّلاَةُ عَلَى وَقْتِهَا ‏"‏‏.‏ قَالَ ثُمَّ أَىُّ قَالَ ‏"‏ ثُمَّ بِرُّ الْوَالِدَيْنِ ‏"‏‏.‏ قَالَ ثُمَّ أَىُّ قَالَ ‏"‏ الْجِهَادُ فِي سَبِيلِ اللَّهِ ‏"‏‏.‏ قَالَ حَدَّثَنِي بِهِنَّ وَلَوِ اسْتَزَدْتُهُ لَزَادَنِي‏.‏\hadithno{527}\hadithtrans{Narrated `Abdullah:I asked the Prophet (ﷺ) "Which deed is the dearest to Allah?" He replied, "To offer the prayers at their early stated fixed times." I asked, "What is the next (in goodness)?" He replied, "To be good and dutiful to your parents" I again asked, "What is the next (in goodness)?" He replied, 'To participate in Jihad (religious fighting) in Allah's cause." `Abdullah added, "I asked only that much and if I had asked more, the Prophet (ﷺ) would have told me more}}
\hadithdefcmd{bukhari}{528}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ حَمْزَةَ، قَالَ حَدَّثَنِي ابْنُ أَبِي حَازِمٍ، وَالدَّرَاوَرْدِيُّ، عَنْ يَزِيدَ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّهُ سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ أَرَأَيْتُمْ لَوْ أَنَّ نَهَرًا بِبَابِ أَحَدِكُمْ، يَغْتَسِلُ فِيهِ كُلَّ يَوْمٍ خَمْسًا، مَا تَقُولُ ذَلِكَ يُبْقِي مِنْ دَرَنِهِ ‏"‏‏.‏ قَالُوا لاَ يُبْقِي مِنْ دَرَنِهِ شَيْئًا‏.‏ قَالَ ‏"‏ فَذَلِكَ مِثْلُ الصَّلَوَاتِ الْخَمْسِ، يَمْحُو اللَّهُ بِهَا الْخَطَايَا ‏"‏‏.‏\hadithno{528}\hadithtrans{Narrated Abu Huraira:I heard Allah's Messenger (ﷺ) saying, "If there was a river at the door of anyone of you and he took a bath in it five times a day would you notice any dirt on him?" They said, "Not a trace of dirt would be left." The Prophet (ﷺ) added, "That is the example of the five prayers with which Allah blots out (annuls) evil deeds}}
\hadithdefcmd{bukhari}{529}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا مَهْدِيٌّ، عَنْ غَيْلاَنَ، عَنْ أَنَسٍ، قَالَ مَا أَعْرِفُ شَيْئًا مِمَّا كَانَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم‏.‏ قِيلَ الصَّلاَةُ‏.‏ قَالَ أَلَيْسَ ضَيَّعْتُمْ مَا ضَيَّعْتُمْ فِيهَا‏.‏\hadithno{529}\hadithtrans{Narrated Ghailan: Anas said, "I do not find (now-a-days) things as they were (practiced) at the time of the Prophet." Somebody said "The prayer (is as it was.)" Anas said, "Have you not done in the prayer what you have done?}}
\hadithdefcmd{bukhari}{530}{حَدَّثَنَا عَمْرُو بْنُ زُرَارَةَ، قَالَ أَخْبَرَنَا عَبْدُ الْوَاحِدِ بْنُ وَاصِلٍ أَبُو عُبَيْدَةَ الْحَدَّادُ، عَنْ عُثْمَانَ بْنِ أَبِي رَوَّادٍ، أَخِي عَبْدِ الْعَزِيزِ قَالَ سَمِعْتُ الزُّهْرِيَّ، يَقُولُ دَخَلْتُ عَلَى أَنَسِ بْنِ مَالِكٍ بِدِمَشْقَ وَهُوَ يَبْكِي فَقُلْتُ مَا يُبْكِيكَ فَقَالَ لاَ أَعْرِفُ شَيْئًا مِمَّا أَدْرَكْتُ إِلاَّ هَذِهِ الصَّلاَةَ، وَهَذِهِ الصَّلاَةُ قَدْ ضُيِّعَتْ‏.‏ وَقَالَ بَكْرٌ حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ أَخْبَرَنَا عُثْمَانُ بْنُ أَبِي رَوَّادٍ نَحْوَهُ‏.‏\hadithno{530}\hadithtrans{Narrated Az-Zuhri that he visited Anas bin Malik at Damascus and found him weeping and asked him why he was weeping. He replied, "I do not know anything which I used to know during the life-time of Allah's Apostle except this prayer which is being lost (not offered as it should be)}}
\hadithdefcmd{bukhari}{531}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ أَحَدَكُمْ إِذَا صَلَّى يُنَاجِي رَبَّهُ فَلاَ يَتْفِلَنَّ عَنْ يَمِينِهِ، وَلَكِنْ تَحْتَ قَدَمِهِ الْيُسْرَى ‏"‏‏.‏ وَقَالَ سَعِيدٌ عَنْ قَتَادَةَ لاَ يَتْفِلُ قُدَّامَهُ أَوْ بَيْنَ يَدَيْهِ، وَلَكِنْ عَنْ يَسَارِهِ أَوْ تَحْتَ قَدَمَيْهِ‏.‏ وَقَالَ شُعْبَةُ لاَ يَبْزُقُ بَيْنَ يَدَيْهِ وَلاَ عَنْ يَمِينِهِ، وَلَكِنْ عَنْ يَسَارِهِ أَوْ تَحْتَ قَدَمِهِ‏.‏ وَقَالَ حُمَيْدٌ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏"‏ لاَ يَبْزُقْ فِي الْقِبْلَةِ وَلاَ عَنْ يَمِينِهِ، وَلَكِنْ عَنْ يَسَارِهِ أَوْ تَحْتَ قَدَمِهِ ‏"‏‏.‏\hadithno{531}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Whenever anyone of you offers his prayer he is speaking in private to his Lord. So he should not spit to his right but under his left foot." Qatada said, "He should not spit in front of him but to his left or under his feet." And Shu`ba said, "He should not spit in front of him, nor to his right but to his left or under his foot." Anas said: The Prophet (ﷺ) said, "He should neither spit in the direction of his Qibla nor to his right but to his left or under his foot}}
\hadithdefcmd{bukhari}{532}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا قَتَادَةُ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ اعْتَدِلُوا فِي السُّجُودِ، وَلاَ يَبْسُطْ ذِرَاعَيْهِ كَالْكَلْبِ، وَإِذَا بَزَقَ فَلاَ يَبْزُقَنَّ بَيْنَ يَدَيْهِ وَلاَ عَنْ يَمِينِهِ، فَإِنَّهُ يُنَاجِي رَبَّهُ ‏"‏‏.‏\hadithno{532}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "Do the prostration properly and do not put your forearms flat with elbows touching the ground like a dog. And if you want to spit, do not spit in front, nor to the right for the person in prayer is speaking in private to his Lord}}
\hadithdefcmd{bukhari}{534}{حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبُو بَكْرٍ، عَنْ سُلَيْمَانَ، قَالَ صَالِحُ بْنُ كَيْسَانَ حَدَّثَنَا الأَعْرَجُ عَبْدُ الرَّحْمَنِ، وَغَيْرُهُ، عَنْ أَبِي هُرَيْرَةَ‏.‏وَنَافِعٌ مَوْلَى عَبْدِ اللَّهِ بْنِ عُمَرَ عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، أَنَّهُمَا حَدَّثَاهُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ، فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏‏.‏\hadithno{534}\hadithtrans{Narrated Abu Huraira and `Abdullah bin `Umar:Allah's Messenger (ﷺ) said, "If it is very hot, then pray the Zuhr prayer when it becomes (a bit) cooler, as the severity of the heat is from the raging of the Hell-fire}}
\hadithdefcmd{bukhari}{535}{حَدَّثَنَا ابْنُ بَشَّارٍ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنِ الْمُهَاجِرِ أَبِي الْحَسَنِ، سَمِعَ زَيْدَ بْنَ وَهْبٍ، عَنْ أَبِي ذَرٍّ، قَالَ أَذَّنَ مُؤَذِّنُ النَّبِيِّ صلى الله عليه وسلم الظُّهْرَ فَقَالَ ‏"‏ أَبْرِدْ أَبْرِدْ ـ أَوْ قَالَ ـ انْتَظِرِ انْتَظِرْ ‏"‏‏.‏ وَقَالَ ‏"‏ شِدَّةُ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ، فَإِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا عَنِ الصَّلاَةِ ‏"‏‏.‏ حَتَّى رَأَيْنَا فَىْءَ التُّلُولِ‏.‏\hadithno{535}\hadithtrans{Narrated Abu Dhar:The Mu'adh-dhin (call-maker) of the Prophet (ﷺ) pronounced the Adhan (call) for the Zuhr prayer but the Prophet said, "Let it be cooler, let it be cooler." Or said, 'Wait, wait, because the severity of heat is from the raging of the Hell-fire. In severe hot weather, pray when it becomes (a bit) cooler and the shadows of hillocks appear}}
\hadithdefcmd{bukhari}{537}{حَدَّثَنَا عَلِيُّ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا سُفْيَانُ، قَالَ حَفِظْنَاهُ مِنَ الزُّهْرِيِّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا بِالصَّلاَةِ، فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏‏.‏ ‏"‏ وَاشْتَكَتِ النَّارُ إِلَى رَبِّهَا فَقَالَتْ يَا رَبِّ أَكَلَ بَعْضِي بَعْضًا‏.‏ فَأَذِنَ لَهَا بِنَفَسَيْنِ نَفَسٍ فِي الشِّتَاءِ، وَنَفَسٍ فِي الصَّيْفِ، فَهُوَ أَشَدُّ مَا تَجِدُونَ مِنَ الْحَرِّ، وَأَشَدُّ مَا تَجِدُونَ مِنَ الزَّمْهَرِيرِ ‏"‏‏.‏\hadithno{537}\hadithtrans{Narrated Abu Huraira:The Prophet (ﷺ) said, "In very hot weather delay the Zuhr prayer till it becomes (a bit) cooler because the severity of heat is from the raging of the Hell-fire. The Hell-fire of Hell complained to its Lord saying: O Lord! My parts are eating (destroying) one another. So Allah allowed it to take two breaths, one in the winter and the other in the summer. The breath in the summer is at the time when you feel the severest heat and the breath in the winter is at the time when you feel the severest cold}}
\hadithdefcmd{bukhari}{538}{حَدَّثَنَا عُمَرُ بْنُ حَفْصٍ، قَالَ حَدَّثَنَا أَبِي قَالَ، حَدَّثَنَا الأَعْمَشُ، حَدَّثَنَا أَبُو صَالِحٍ، عَنْ أَبِي سَعِيدٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَبْرِدُوا بِالظُّهْرِ، فَإِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ ‏"‏‏.‏ تَابَعَهُ سُفْيَانُ وَيَحْيَى وَأَبُو عَوَانَةَ عَنِ الأَعْمَشِ‏.‏\hadithno{538}\hadithtrans{Narrated Abu Sa`id:that Allah's Messenger (ﷺ) said, "Pray Zuhr prayer when it becomes (a bit) cooler as the severity of heat is from the raging of the Hell-fire}}
\hadithdefcmd{bukhari}{539}{حَدَّثَنَا آدَمُ بْنُ أَبِي إِيَاسٍ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا مُهَاجِرٌ أَبُو الْحَسَنِ، مَوْلًى لِبَنِي تَيْمِ اللَّهِ قَالَ سَمِعْتُ زَيْدَ بْنَ وَهْبٍ، عَنْ أَبِي ذَرٍّ الْغِفَارِيِّ، قَالَ كُنَّا مَعَ النَّبِيِّ صلى الله عليه وسلم فِي سَفَرٍ، فَأَرَادَ الْمُؤَذِّنُ أَنْ يُؤَذِّنَ لِلظُّهْرِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَبْرِدْ ‏"‏‏.‏ ثُمَّ أَرَادَ أَنْ يُؤَذِّنَ فَقَالَ لَهُ ‏"‏ أَبْرِدْ ‏"‏‏.‏ حَتَّى رَأَيْنَا فَىْءَ التُّلُولِ، فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِنَّ شِدَّةَ الْحَرِّ مِنْ فَيْحِ جَهَنَّمَ، فَإِذَا اشْتَدَّ الْحَرُّ فَأَبْرِدُوا بِالصَّلاَةِ ‏"‏‏.‏ وَقَالَ ابْنُ عَبَّاسٍ تَتَفَيَّأُ تَتَمَيَّلُ‏.‏\hadithno{539}\hadithtrans{Narrated Abu Dhar Al-Ghifar:We were with the Prophet (ﷺ) on a journey and the Mu'adh-dhin (call maker for the prayer) wanted to pronounce the Adhan (call) for the Zuhr prayer. The Prophet (ﷺ) said, 'Let it become cooler." He again (after a while) wanted to pronounce the Adhan but the Prophet (ﷺ) said to him, "Let it become cooler till we see the shadows of hillocks." The Prophet (ﷺ) added, "The severity of heat is from the raging of the Hell-fire, and in very hot weather pray (Zuhr) when it becomes cooler}}
\hadithdefcmd{bukhari}{540}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ أَخْبَرَنِي أَنَسُ بْنُ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم خَرَجَ حِينَ زَاغَتِ الشَّمْسُ فَصَلَّى الظُّهْرَ، فَقَامَ عَلَى الْمِنْبَرِ، فَذَكَرَ السَّاعَةَ، فَذَكَرَ أَنَّ فِيهَا أُمُورًا عِظَامًا ثُمَّ قَالَ ‏"‏ مَنْ أَحَبَّ أَنْ يَسْأَلَ عَنْ شَىْءٍ فَلْيَسْأَلْ، فَلاَ تَسْأَلُونِي عَنْ شَىْءٍ إِلاَّ أَخْبَرْتُكُمْ مَا دُمْتُ فِي مَقَامِي هَذَا ‏"‏‏.‏ فَأَكْثَرَ النَّاسُ فِي الْبُكَاءِ، وَأَكْثَرَ أَنْ يَقُولَ ‏"‏ سَلُونِي ‏"‏‏.‏ فَقَامَ عَبْدُ اللَّهِ بْنُ حُذَافَةَ السَّهْمِيُّ فَقَالَ مَنْ أَبِي قَالَ ‏"‏ أَبُوكَ حُذَافَةُ ‏"‏‏.‏ ثُمَّ أَكْثَرَ أَنْ يَقُولَ ‏"‏ سَلُونِي ‏"‏‏.‏ فَبَرَكَ عُمَرُ عَلَى رُكْبَتَيْهِ فَقَالَ رَضِينَا بِاللَّهِ رَبًّا، وَبِالإِسْلاَمِ دِينًا، وَبِمُحَمَّدٍ نَبِيًّا‏.‏ فَسَكَتَ ثُمَّ قَالَ ‏"‏ عُرِضَتْ عَلَىَّ الْجَنَّةُ وَالنَّارُ آنِفًا فِي عُرْضِ هَذَا الْحَائِطِ فَلَمْ أَرَ كَالْخَيْرِ وَالشَّرِّ ‏"‏‏.‏\hadithno{540}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) came out as the sun declined at midday and offered the Zuhr prayer. He then stood on the pulpit and spoke about the Hour (Day of Judgment) and said that in it there would be tremendous things. He then said, "Whoever likes to ask me about anything he can do so and I shall reply as long as I am at this place of mine. Most of the people wept and the Prophet (ﷺ) said repeatedly, "Ask me." `Abdullah bin Hudhafa As-Sahmi stood up and said, "Who is my father?" The Prophet (ﷺ) said, "Your father is Hudhafa." The Prophet (ﷺ) repeatedly said, "Ask me." Then `Umar knelt before him and said, "We are pleased with Allah as our Lord, Islam as our religion, and Muhammad as our Prophet." The Prophet then became quiet and said, "Paradise and Hell-fire were displayed in front of me on this wall just now and I have never seen a better thing (than the former) and a worse thing (than the latter)}}
\hadithdefcmd{bukhari}{541}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي الْمِنْهَالِ، عَنْ أَبِي بَرْزَةَ، كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الصُّبْحَ وَأَحَدُنَا يَعْرِفُ جَلِيسَهُ، وَيَقْرَأُ فِيهَا مَا بَيْنَ السِّتِّينَ إِلَى الْمِائَةِ، وَيُصَلِّي الظُّهْرَ إِذَا زَالَتِ الشَّمْسُ، وَالْعَصْرَ وَأَحَدُنَا يَذْهَبُ إِلَى أَقْصَى الْمَدِينَةِ ثُمَّ يَرْجِعُ وَالشَّمْسُ حَيَّةٌ، وَنَسِيتُ مَا قَالَ فِي الْمَغْرِبِ، وَلاَ يُبَالِي بِتَأْخِيرِ الْعِشَاءِ إِلَى ثُلُثِ اللَّيْلِ‏.‏ ثُمَّ قَالَ إِلَى شَطْرِ اللَّيْلِ‏.‏ وَقَالَ مُعَاذٌ قَالَ شُعْبَةُ ثُمَّ لَقِيتُهُ مَرَّةً فَقَالَ أَوْ ثُلُثِ اللَّيْلِ‏.‏\hadithno{541}\hadithtrans{Narrated Abu Al-Minhal:Abu Barza said, "The Prophet (ﷺ) used to offer the Fajr (prayer) when one could recognize the person sitting by him (after the prayer) and he used to recite between 60 to 100 Ayat (verses) of the Qur'an. He used to offer the Zuhr prayer as soon as the sun declined (at noon) and the `Asr prayer at a time when a man might go and return from the farthest place in Medina and find the sun still hot. (The sub-narrator forgot what was said about the Maghrib). He did not mind delaying the `Isha prayer to one third of the night or the middle of the night}}
\hadithdefcmd{bukhari}{542}{حَدَّثَنَا مُحَمَّدٌ ـ يَعْنِي ابْنَ مُقَاتِلٍ ـ قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا خَالِدُ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنِي غَالِبٌ الْقَطَّانُ، عَنْ بَكْرِ بْنِ عَبْدِ اللَّهِ الْمُزَنِيِّ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا إِذَا صَلَّيْنَا خَلْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالظَّهَائِرِ فَسَجَدْنَا عَلَى ثِيَابِنَا اتِّقَاءَ الْحَرِّ‏.‏\hadithno{542}\hadithtrans{Narrated Anas bin Malik:When we offered the Zuhr prayers behind Allah's Messenger (ﷺ) we used to prostrate on our clothes to protect ourselves from the heat}}
\hadithdefcmd{bukhari}{543}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا حَمَّادٌ ـ هُوَ ابْنُ زَيْدٍ ـ عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ جَابِرِ بْنِ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم صَلَّى بِالْمَدِينَةِ سَبْعًا وَثَمَانِيًا الظُّهْرَ وَالْعَصْرَ، وَالْمَغْرِبَ وَالْعِشَاءَ‏.‏ فَقَالَ أَيُّوبُ لَعَلَّهُ فِي لَيْلَةٍ مَطِيرَةٍ‏.‏ قَالَ عَسَى‏.‏\hadithno{543}\hadithtrans{Narrated Ibn `Abbas:"The Prophet (ﷺ) prayed eight rak`at for the Zuhr and `Asr, and seven for the Maghrib and `Isha prayers in Medina." Aiyub said, "Perhaps those were rainy nights." Anas said, "May be}}
\hadithdefcmd{bukhari}{544}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ، قَالَ حَدَّثَنَا أَنَسُ بْنُ عِيَاضٍ، عَنْ هِشَامٍ، عَنْ أَبِيهِ، أَنَّ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْعَصْرَ وَالشَّمْسُ لَمْ تَخْرُجْ مِنْ حُجْرَتِهَا‏.‏ وَقَالَ أَبُو أُسَامَةَ عَنْ هِشَامٍ مِنْ قَعْرِ حُجْرَتِهَا‏.‏\hadithno{544}\hadithtrans{Narrated Aisha:Allah's Messenger (ﷺ) used to offer the `Asr prayer when the sunshine had not disappeared from my chamber}}
\hadithdefcmd{bukhari}{545}{حَدَّثَنَا قُتَيْبَةُ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم صَلَّى الْعَصْرَ وَالشَّمْسُ فِي حُجْرَتِهَا، لَمْ يَظْهَرِ الْفَىْءُ مِنْ حُجْرَتِهَا‏.‏\hadithno{545}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) used to offer the `Asr prayers at a time when the sunshine was still inside my chamber and no shadow had yet appeared in it}}
\hadithdefcmd{bukhari}{546}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ أَخْبَرَنَا ابْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي صَلاَةَ الْعَصْرِ وَالشَّمْسُ طَالِعَةٌ فِي حُجْرَتِي لَمْ يَظْهَرِ الْفَىْءُ بَعْدُ‏.‏ وَقَالَ مَالِكٌ وَيَحْيَى بْنُ سَعِيدٍ وَشُعَيْبٌ وَابْنُ أَبِي حَفْصَةَ وَالشَّمْسُ قَبْلَ أَنْ تَظْهَرَ‏.‏\hadithno{546}\hadithtrans{Narrated Aisha:The Prophet (ﷺ) used to pray the `Asr prayers at a time when the sunshine was still inside my chamber and no shadow had yet appeared in it}}
\hadithdefcmd{bukhari}{547}{حَدَّثَنَا مُحَمَّدُ بْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا عَوْفٌ، عَنْ سَيَّارِ بْنِ سَلاَمَةَ، قَالَ دَخَلْتُ أَنَا وَأَبِي، عَلَى أَبِي بَرْزَةَ الأَسْلَمِيِّ، فَقَالَ لَهُ أَبِي كَيْفَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْمَكْتُوبَةَ فَقَالَ كَانَ يُصَلِّي الْهَجِيرَ الَّتِي تَدْعُونَهَا الأُولَى حِينَ تَدْحَضُ الشَّمْسُ، وَيُصَلِّي الْعَصْرَ، ثُمَّ يَرْجِعُ أَحَدُنَا إِلَى رَحْلِهِ فِي أَقْصَى الْمَدِينَةِ وَالشَّمْسُ حَيَّةٌ ـ وَنَسِيتُ مَا قَالَ فِي الْمَغْرِبِ ـ وَكَانَ يَسْتَحِبُّ أَنْ يُؤَخِّرَ الْعِشَاءَ الَّتِي تَدْعُونَهَا الْعَتَمَةَ، وَكَانَ يَكْرَهُ النَّوْمَ قَبْلَهَا وَالْحَدِيثَ بَعْدَهَا، وَكَانَ يَنْفَتِلُ مِنْ صَلاَةِ الْغَدَاةِ حِينَ يَعْرِفُ الرَّجُلُ جَلِيسَهُ، وَيَقْرَأُ بِالسِّتِّينَ إِلَى الْمِائَةِ‏.‏\hadithno{547}\hadithtrans{Narrated Saiyar bin Salama:I along with my father went to Abu- Barza Al-Aslami and my father asked him, "How Allah's Messenger (ﷺ) used to offer the five compulsory congregational prayers?" Abu- Barza said, "The Prophet (ﷺ) used to pray the Zuhr prayer which you (people) call the first one at midday when the sun had just declined The `Asr prayer at a time when after the prayer, a man could go to the house at the farthest place in Medina (and arrive) while the sun was still hot. (I forgot about the Maghrib prayer). The Prophet (ﷺ) Loved to delay the `Isha which you call Al- `Atama [??] and he disliked sleeping before it and speaking after it. After the Fajr prayer he used to leave when a man could recognize the one sitting beside him and he used to recite between 60 to 100 Ayat (in the Fajr prayer)}}
\hadithdefcmd{bukhari}{548}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا نُصَلِّي الْعَصْرَ ثُمَّ يَخْرُجُ الإِنْسَانُ إِلَى بَنِي عَمْرِو بْنِ عَوْفٍ فَنَجِدُهُمْ يُصَلُّونَ الْعَصْرَ‏.‏\hadithno{548}\hadithtrans{Narrated Anas bin Malik:We used to pray the `Asr prayer and after that if someone happened to go to the tribe of Bani `Amr bin `Auf, he would find them still praying the `Asr (prayer)}}
\hadithdefcmd{bukhari}{549}{حَدَّثَنَا ابْنُ مُقَاتِلٍ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا أَبُو بَكْرِ بْنُ عُثْمَانَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ صَلَّيْنَا مَعَ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ الظُّهْرَ، ثُمَّ خَرَجْنَا حَتَّى دَخَلْنَا عَلَى أَنَسِ بْنِ مَالِكٍ فَوَجَدْنَاهُ يُصَلِّي الْعَصْرَ فَقُلْتُ يَا عَمِّ، مَا هَذِهِ الصَّلاَةُ الَّتِي صَلَّيْتَ قَالَ الْعَصْرُ، وَهَذِهِ صَلاَةُ رَسُولِ اللَّهِ صلى الله عليه وسلم الَّتِي كُنَّا نُصَلِّي مَعَهُ‏.‏\hadithno{549}\hadithtrans{Narrated Abu Bakr bin `Uthman bin Sahl bin Hunaif:that he heard Abu Umama saying: We prayed the Zuhr prayer with `Umar bin `Abdul `Aziz and then went to Anas bin Malik and found him offering the `Asr prayer. I asked him, "O uncle! Which prayer have you offered?" He said 'The `Asr and this is (the time of) the prayer of Allah's Apostle which we used to pray with him}}
\hadithdefcmd{bukhari}{550}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي أَنَسُ بْنُ مَالِكٍ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْعَصْرَ وَالشَّمْسُ مُرْتَفِعَةٌ حَيَّةٌ، فَيَذْهَبُ الذَّاهِبُ إِلَى الْعَوَالِي فَيَأْتِيهِمْ وَالشَّمْسُ مُرْتَفِعَةٌ، وَبَعْضُ الْعَوَالِي مِنَ الْمَدِينَةِ عَلَى أَرْبَعَةِ أَمْيَالٍ أَوْ نَحْوِهِ‏.‏\hadithno{550}\hadithtrans{Narrated Anas bin Malik:Allah's Messenger (ﷺ) used to offer the `Asr prayer at a time when the sun was still hot and high and if a person went to Al-`Awali (a place) of Medina, he would reach there when the sun was still high. Some of Al-`Awali of Medina were about four miles or so from the town}}
\hadithdefcmd{bukhari}{551}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ كُنَّا نُصَلِّي الْعَصْرَ ثُمَّ يَذْهَبُ الذَّاهِبُ مِنَّا إِلَى قُبَاءٍ، فَيَأْتِيهِمْ وَالشَّمْسُ مُرْتَفِعَةٌ‏.‏\hadithno{551}\hadithtrans{Narrated Anas bin Malik:We used to pray the `Asr and after that if one of us went to Quba' he would arrive there while the sun was still high}}
\hadithdefcmd{bukhari}{552}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ الَّذِي تَفُوتُهُ صَلاَةُ الْعَصْرِ كَأَنَّمَا وُتِرَ أَهْلَهُ وَمَالَهُ ‏"‏‏.‏\hadithno{552}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "Whoever misses the `Asr prayer (intentionally) then it is as if he lost his family and property}}
\hadithdefcmd{bukhari}{553}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي الْمَلِيحِ، قَالَ كُنَّا مَعَ بُرَيْدَةَ فِي غَزْوَةٍ فِي يَوْمٍ ذِي غَيْمٍ فَقَالَ بَكِّرُوا بِصَلاَةِ الْعَصْرِ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَرَكَ صَلاَةَ الْعَصْرِ فَقَدْ حَبِطَ عَمَلُهُ ‏"‏‏.‏\hadithno{553}\hadithtrans{Narrated Abu Al-Malih [??]:We were with Buraida in a battle on a cloudy day and he said, "Offer the `Asr prayer early as the Prophet said, "Whoever leaves the `Asr prayer, all his (good) deeds will be annulled}}
\hadithdefcmd{bukhari}{554}{حَدَّثَنَا الْحُمَيْدِيُّ، قَالَ حَدَّثَنَا مَرْوَانُ بْنُ مُعَاوِيَةَ، قَالَ حَدَّثَنَا إِسْمَاعِيلُ، عَنْ قَيْسٍ، عَنْ جَرِيرٍ، قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَنَظَرَ إِلَى الْقَمَرِ لَيْلَةً ـ يَعْنِي الْبَدْرَ ـ فَقَالَ ‏"‏ إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ هَذَا الْقَمَرَ لاَ تُضَامُّونَ فِي رُؤْيَتِهِ، فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا فَافْعَلُوا ‏"‏‏.‏ ثُمَّ قَرَأَ ‏\{‏وَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ الْغُرُوبِ‏\}‏‏.‏ قَالَ إِسْمَاعِيلُ افْعَلُوا لاَ تَفُوتَنَّكُمْ‏.‏\hadithno{554}\hadithtrans{Narrated Qais:Jarir said, "We were with the Prophet (ﷺ) and he looked at the moon--full-moon--and said, 'Certainly you will see your Lord as you see this moon and you will have no trouble in seeing Him. So if you can avoid missing (through sleep or business, etc.) a prayer before the sunrise (Fajr) and a prayer before sunset (`Asr), you must do so.' He then recited Allah's Statement: And celebrate the praises Of your Lord before the rising of the sun and before (its) setting." (50.39) Isma`il said, "Offer those prayers and do not miss them}}
\hadithdefcmd{bukhari}{555}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ حَدَّثَنَا مَالِكٌ، عَنْ أَبِي الزِّنَادِ، عَنِ الأَعْرَجِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ يَتَعَاقَبُونَ فِيكُمْ مَلاَئِكَةٌ بِاللَّيْلِ وَمَلاَئِكَةٌ بِالنَّهَارِ، وَيَجْتَمِعُونَ فِي صَلاَةِ الْفَجْرِ وَصَلاَةِ الْعَصْرِ، ثُمَّ يَعْرُجُ الَّذِينَ بَاتُوا فِيكُمْ، فَيَسْأَلُهُمْ وَهْوَ أَعْلَمُ بِهِمْ كَيْفَ تَرَكْتُمْ عِبَادِي فَيَقُولُونَ تَرَكْنَاهُمْ وَهُمْ يُصَلُّونَ، وَأَتَيْنَاهُمْ وَهُمْ يُصَلُّونَ ‏"‏‏.‏\hadithno{555}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Angels come to you in succession by night and day and all of them get together at the time of the Fajr and `Asr prayers. Those who have passed the night with you (or stayed with you) ascend (to the Heaven) and Allah asks them, though He knows everything about you, well, "In what state did you leave my slaves?" The angels reply: "When we left them they were praying and when we reached them, they were praying}}
\hadithdefcmd{bukhari}{556}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا شَيْبَانُ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا أَدْرَكَ أَحَدُكُمْ سَجْدَةً مِنْ صَلاَةِ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَلْيُتِمَّ صَلاَتَهُ، وَإِذَا أَدْرَكَ سَجْدَةً مِنْ صَلاَةِ الصُّبْحِ قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَلْيُتِمَّ صَلاَتَهُ ‏"‏‏.‏\hadithno{556}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "If anyone of you can get one rak`a of the `Asr prayer before sunset, he should complete his prayer. If any of you can get one rak`a of the Fajr prayer before sunrise, he should complete his prayer}}
\hadithdefcmd{bukhari}{557}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنِي إِبْرَاهِيمُ، عَنِ ابْنِ شِهَابٍ، عَنْ سَالِمِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، أَنَّهُ أَخْبَرَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنَّمَا بَقَاؤُكُمْ فِيمَا سَلَفَ قَبْلَكُمْ مِنَ الأُمَمِ كَمَا بَيْنَ صَلاَةِ الْعَصْرِ إِلَى غُرُوبِ الشَّمْسِ، أُوتِيَ أَهْلُ التَّوْرَاةِ التَّوْرَاةَ فَعَمِلُوا حَتَّى إِذَا انْتَصَفَ النَّهَارُ عَجَزُوا، فَأُعْطُوا قِيرَاطًا قِيرَاطًا، ثُمَّ أُوتِيَ أَهْلُ الإِنْجِيلِ الإِنْجِيلَ فَعَمِلُوا إِلَى صَلاَةِ الْعَصْرِ، ثُمَّ عَجَزُوا، فَأُعْطُوا قِيرَاطًا قِيرَاطًا، ثُمَّ أُوتِينَا الْقُرْآنَ فَعَمِلْنَا إِلَى غُرُوبِ الشَّمْسِ، فَأُعْطِينَا قِيرَاطَيْنِ قِيرَاطَيْنِ، فَقَالَ أَهْلُ الْكِتَابَيْنِ أَىْ رَبَّنَا أَعْطَيْتَ هَؤُلاَءِ قِيرَاطَيْنِ قِيرَاطَيْنِ، وَأَعْطَيْتَنَا قِيرَاطًا قِيرَاطًا، وَنَحْنُ كُنَّا أَكْثَرَ عَمَلاً، قَالَ قَالَ اللَّهُ عَزَّ وَجَلَّ هَلْ ظَلَمْتُكُمْ مِنْ أَجْرِكُمْ مِنْ شَىْءٍ قَالُوا لاَ، قَالَ فَهْوَ فَضْلِي أُوتِيهِ مَنْ أَشَاءُ ‏"‏‏.‏\hadithno{557}\hadithtrans{Narrated Salim bin `Abdullah:My father said, "I heard Allah's Messenger (ﷺ) saying, 'The period of your stay as compared to the previous nations is like the period equal to the time between the `Asr prayer and sunset. The people of the Torah were given the Torah and they acted (upon it) till midday then they were exhausted and were given one Qirat (of gold) each. And then the people of the Gospel were given the Gospel and they acted (upon it) till the `Asr prayer then they were exhausted and were given one Qirat each. And then we were given the Qur'an and we acted (upon it) till sunset and we were given two Qirats each. On that the people of both the scriptures said, 'O our Lord! You have given them two Qirats and given us one Qirat, though we have worked more than they.' Allah said, 'Have I usurped some of your right?' They said, 'No.' Allah said: "That is my blessing I bestow upon whomsoever I wish}}
\hadithdefcmd{bukhari}{558}{حَدَّثَنَا أَبُو كُرَيْبٍ، قَالَ حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ مَثَلُ الْمُسْلِمِينَ وَالْيَهُودِ وَالنَّصَارَى كَمَثَلِ رَجُلٍ اسْتَأْجَرَ قَوْمًا يَعْمَلُونَ لَهُ عَمَلاً إِلَى اللَّيْلِ، فَعَمِلُوا إِلَى نِصْفِ النَّهَارِ، فَقَالُوا لاَ حَاجَةَ لَنَا إِلَى أَجْرِكَ، فَاسْتَأْجَرَ آخَرِينَ فَقَالَ أَكْمِلُوا بَقِيَّةَ يَوْمِكُمْ، وَلَكُمُ الَّذِي شَرَطْتُ، فَعَمِلُوا حَتَّى إِذَا كَانَ حِينَ صَلاَةِ الْعَصْرِ قَالُوا لَكَ مَا عَمِلْنَا‏.‏ فَاسْتَأْجَرَ قَوْمًا فَعَمِلُوا بَقِيَّةَ يَوْمِهِمْ حَتَّى غَابَتِ الشَّمْسُ، وَاسْتَكْمَلُوا أَجْرَ الْفَرِيقَيْنِ ‏"‏‏.‏\hadithno{558}\hadithtrans{Narrated Abu Musa:The Prophet (ﷺ) said, "The example of Muslims, Jews and Christians is like the example of a man who employed laborers to work for him from morning till night. They worked till midday and they said, 'We are not in need of your reward.' So the man employed another batch and said to them, 'Complete the rest of the day and yours will be the wages I had fixed (for the first batch). They worked until the time of the `Asr prayer and said, 'Whatever we have done is for you.' He employed another batch. They worked for the rest of the day till sunset, and they received the wages of the two former batches}}
\hadithdefcmd{bukhari}{559}{حَدَّثَنَا مُحَمَّدُ بْنُ مِهْرَانَ، قَالَ حَدَّثَنَا الْوَلِيدُ، قَالَ حَدَّثَنَا الأَوْزَاعِيُّ، قَالَ حَدَّثَنَا أَبُو النَّجَاشِيِّ، صُهَيْبٌ مَوْلَى رَافِعِ بْنِ خَدِيجٍ قَالَ سَمِعْتُ رَافِعَ بْنَ خَدِيجٍ، يَقُولُ كُنَّا نُصَلِّي الْمَغْرِبَ مَعَ النَّبِيِّ صلى الله عليه وسلم فَيَنْصَرِفُ أَحَدُنَا وَإِنَّهُ لَيُبْصِرُ مَوَاقِعَ نَبْلِهِ‏.‏\hadithno{559}\hadithtrans{Narrated Rafi` bin Khadij:We used to offer the Maghrib prayer with the Prophet (ﷺ) and after finishing the prayer one of us may go away and could still see as far as the spots where one's arrow might reach when shot by a bow}}
\hadithdefcmd{bukhari}{560}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدٍ، عَنْ مُحَمَّدِ بْنِ عَمْرِو بْنِ الْحَسَنِ بْنِ عَلِيٍّ، قَالَ قَدِمَ الْحَجَّاجُ فَسَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ فَقَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّي الظُّهْرَ بِالْهَاجِرَةِ، وَالْعَصْرَ وَالشَّمْسُ نَقِيَّةٌ، وَالْمَغْرِبَ إِذَا وَجَبَتْ، وَالْعِشَاءَ أَحْيَانًا وَأَحْيَانًا، إِذَا رَآهُمُ اجْتَمَعُوا عَجَّلَ، وَإِذَا رَآهُمْ أَبْطَوْا أَخَّرَ، وَالصُّبْحَ كَانُوا ـ أَوْ كَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّيهَا بِغَلَسٍ‏.‏\hadithno{560}\hadithtrans{Narrated Jabir bin `Abdullah:The Prophet (ﷺ) used to pray the Zuhr at midday, and the `Asr at a time when the sun was still bright, the Maghrib after sunset (at its stated time) and the `Isha at a variable time. Whenever he saw the people assembled (for `Isha' prayer) he would pray earlier and if the people delayed, he would delay the prayer. And they or the Prophet (ﷺ) used to offer the Fajr Prayers when it was still dark}}
\hadithdefcmd{bukhari}{561}{حَدَّثَنَا الْمَكِّيُّ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا يَزِيدُ بْنُ أَبِي عُبَيْدٍ، عَنْ سَلَمَةَ، قَالَ كُنَّا نُصَلِّي مَعَ النَّبِيِّ صلى الله عليه وسلم الْمَغْرِبَ إِذَا تَوَارَتْ بِالْحِجَابِ‏.‏\hadithno{561}\hadithtrans{Narrated Salama:We used to pray the Maghrib prayer with the Prophet (ﷺ) when the sun disappeared from the horizon}}
\hadithdefcmd{bukhari}{562}{حَدَّثَنَا آدَمُ، قَالَ حَدَّثَنَا شُعْبَةُ، قَالَ حَدَّثَنَا عَمْرُو بْنُ دِينَارٍ، قَالَ سَمِعْتُ جَابِرَ بْنَ زَيْدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم سَبْعًا جَمِيعًا وَثَمَانِيًا جَمِيعًا‏.‏\hadithno{562}\hadithtrans{Narrated Ibn `Abbas:The Prophet (ﷺ) prayed seven rak`at together and eight rak`at together}}
\hadithdefcmd{bukhari}{563}{حَدَّثَنَا أَبُو مَعْمَرٍ ـ هُوَ عَبْدُ اللَّهِ بْنُ عَمْرٍو ـ قَالَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنِ الْحُسَيْنِ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ بُرَيْدَةَ، قَالَ حَدَّثَنِي عَبْدُ اللَّهِ الْمُزَنِيُّ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ تَغْلِبَنَّكُمُ الأَعْرَابُ عَلَى اسْمِ صَلاَتِكُمُ الْمَغْرِبِ ‏"‏‏.‏ قَالَ الأَعْرَابُ وَتَقُولُ هِيَ الْعِشَاءُ‏.‏\hadithno{563}\hadithtrans{Narrated `Abdullah Al-Muzani:The Prophet (ﷺ) said, "Do not be influenced by bedouins regarding the name of your Maghrib prayer which is called `Isha' by them}}
\hadithdefcmd{bukhari}{564}{حَدَّثَنَا عَبْدَانُ، قَالَ أَخْبَرَنَا عَبْدُ اللَّهِ، قَالَ أَخْبَرَنَا يُونُسُ، عَنِ الزُّهْرِيِّ، قَالَ سَالِمٌ أَخْبَرَنِي عَبْدُ اللَّهِ، قَالَ صَلَّى لَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً صَلاَةَ الْعِشَاءِ ـ وَهْىَ الَّتِي يَدْعُو النَّاسُ الْعَتَمَةَ ـ ثُمَّ انْصَرَفَ فَأَقْبَلَ عَلَيْنَا فَقَالَ ‏ "‏ أَرَأَيْتُمْ لَيْلَتَكُمْ هَذِهِ فَإِنَّ رَأْسَ مِائَةِ سَنَةٍ مِنْهَا لاَ يَبْقَى مِمَّنْ هُوَ عَلَى ظَهْرِ الأَرْضِ أَحَدٌ ‏"‏‏.‏\hadithno{564}\hadithtrans{Narrated `Abdullah:"One night Allah's Messenger (ﷺ) led us in the `Isha' prayer and that is the one called Al-`Atma [??] by the people. After the completion of the prayer, he faced us and said, "Do you know the importance of this night? Nobody present on the surface of the earth tonight will be living after one hundred years from this night." (See Hadith No)}}
\hadithdefcmd{bukhari}{565}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ سَعْدِ بْنِ إِبْرَاهِيمَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو ـ هُوَ ابْنُ الْحَسَنِ بْنِ عَلِيٍّ ـ قَالَ سَأَلْنَا جَابِرَ بْنَ عَبْدِ اللَّهِ عَنْ صَلاَةِ النَّبِيِّ، صلى الله عليه وسلم فَقَالَ كَانَ يُصَلِّي الظُّهْرَ بِالْهَاجِرَةِ، وَالْعَصْرَ وَالشَّمْسُ حَيَّةٌ، وَالْمَغْرِبَ إِذَا وَجَبَتْ، وَالْعِشَاءَ إِذَا كَثُرَ النَّاسُ عَجَّلَ، وَإِذَا قَلُّوا أَخَّرَ، وَالصُّبْحَ بِغَلَسٍ‏.‏\hadithno{565}\hadithtrans{Narrated Muhammad bin `Amr:We asked Jabir bin `Abdullah about the prayers of the Prophet (ﷺ) . He said, "He used to pray Zuhr prayer at midday, the `Asr when the sun was still hot, and the Maghrib after sunset (at its stated time). The `Isha was offered early if the people gathered, and used to be delayed if their number was less; and the morning prayer was offered when it was still dark}}
\hadithdefcmd{bukhari}{566}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ حَدَّثَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ قَالَتْ، أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً بِالْعِشَاءِ، وَذَلِكَ قَبْلَ أَنْ يَفْشُوَ الإِسْلاَمُ، فَلَمْ يَخْرُجْ حَتَّى قَالَ عُمَرُ نَامَ النِّسَاءُ وَالصِّبْيَانُ‏.‏ فَخَرَجَ فَقَالَ لأَهْلِ الْمَسْجِدِ ‏ "‏ مَا يَنْتَظِرُهَا أَحَدٌ مِنْ أَهْلِ الأَرْضِ غَيْرُكُمْ ‏"‏‏.‏\hadithno{566}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) once delayed the `Isha' prayer and that was during the days when Islam still had not spread. The Prophet (ﷺ) did not come out till `Umar informed him that the women and children had slept. Then he came out and said to the people of the mosque: "None amongst the dwellers of the earth has been waiting for it (`Isha prayer) except you}}
\hadithdefcmd{bukhari}{567}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، قَالَ أَخْبَرَنَا أَبُو أُسَامَةَ، عَنْ بُرَيْدٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ كُنْتُ أَنَا وَأَصْحَابِي الَّذِينَ، قَدِمُوا مَعِي فِي السَّفِينَةِ نُزُولاً فِي بَقِيعِ بُطْحَانَ، وَالنَّبِيُّ صلى الله عليه وسلم بِالْمَدِينَةِ، فَكَانَ يَتَنَاوَبُ النَّبِيَّ صلى الله عليه وسلم عِنْدَ صَلاَةِ الْعِشَاءِ كُلَّ لَيْلَةٍ نَفَرٌ مِنْهُمْ، فَوَافَقْنَا النَّبِيَّ ـ عليه السلام ـ أَنَا وَأَصْحَابِي وَلَهُ بَعْضُ الشُّغْلِ فِي بَعْضِ أَمْرِهِ فَأَعْتَمَ بِالصَّلاَةِ حَتَّى ابْهَارَّ اللَّيْلُ، ثُمَّ خَرَجَ النَّبِيُّ صلى الله عليه وسلم فَصَلَّى بِهِمْ، فَلَمَّا قَضَى صَلاَتَهُ قَالَ لِمَنْ حَضَرَهُ ‏"‏ عَلَى رِسْلِكُمْ، أَبْشِرُوا إِنَّ مِنْ نِعْمَةِ اللَّهِ عَلَيْكُمْ أَنَّهُ لَيْسَ أَحَدٌ مِنَ النَّاسِ يُصَلِّي هَذِهِ السَّاعَةَ غَيْرُكُمْ ‏"‏‏.‏ أَوْ قَالَ ‏"‏ مَا صَلَّى هَذِهِ السَّاعَةَ أَحَدٌ غَيْرُكُمْ ‏"‏‏.‏ لاَ يَدْرِي أَىَّ الْكَلِمَتَيْنِ قَالَ‏.‏ قَالَ أَبُو مُوسَى فَرَجَعْنَا فَفَرِحْنَا بِمَا سَمِعْنَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{567}\hadithtrans{Narrated Abu Musa:My companions, who came with me in the boat and I landed at a place called Baqi [??] Buthan [??] . The Prophet (ﷺ) was in Medina at that time. One of us used to go to the Prophet (ﷺ) by turns every night at the time of the `Isha prayer. Once I along with my companions went to the Prophet (ﷺ) and he was busy in some of his affairs, so the `Isha' prayer was delayed to the middle of the night He then came out and led the people (in prayer). After finishing from the prayer, he addressed the people present there saying, "Be patient! Don't go away. Have the glad tiding. It is from the blessing of Allah upon you that none amongst mankind has prayed at this time save you." Or said, "None except you has prayed at this time." Abu Musa added, 'So we returned happily after what we heard from Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{568}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، قَالَ أَخْبَرَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، قَالَ حَدَّثَنَا خَالِدٌ الْحَذَّاءُ، عَنْ أَبِي الْمِنْهَالِ، عَنْ أَبِي بَرْزَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ يَكْرَهُ النَّوْمَ قَبْلَ الْعِشَاءِ وَالْحَدِيثَ بَعْدَهَا‏.‏\hadithno{568}\hadithtrans{Narrated Abu Barza:Allah's Messenger (ﷺ) disliked to sleep before the `Isha' prayer and to talk after it}}
\hadithdefcmd{bukhari}{569}{حَدَّثَنَا أَيُّوبُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنِي أَبُو بَكْرٍ، عَنْ سُلَيْمَانَ، قَالَ صَالِحُ بْنُ كَيْسَانَ أَخْبَرَنِي ابْنُ شِهَابٍ، عَنْ عُرْوَةَ، أَنَّ عَائِشَةَ، قَالَتْ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْعِشَاءِ حَتَّى نَادَاهُ عُمَرُ الصَّلاَةَ، نَامَ النِّسَاءُ وَالصِّبْيَانُ‏.‏ فَخَرَجَ فَقَالَ ‏ "‏ مَا يَنْتَظِرُهَا أَحَدٌ مِنْ أَهْلِ الأَرْضِ غَيْرُكُمْ ‏"‏‏.‏ قَالَ وَلاَ يُصَلَّى يَوْمَئِذٍ إِلاَّ بِالْمَدِينَةِ، وَكَانُوا يُصَلُّونَ فِيمَا بَيْنَ أَنْ يَغِيبَ الشَّفَقُ إِلَى ثُلُثِ اللَّيْلِ الأَوَّلِ‏.‏\hadithno{569}\hadithtrans{Narrated Ibn Shihab from `Urwa:`Aisha said, "Once Allah's Messenger (ﷺ) delayed the `Isha' prayer till `Umar reminded him by saying, "The prayer!" The women and children have slept. Then the Prophet (ﷺ) came out and said, 'None amongst the dwellers of the earth has been waiting for it (the prayer) except you." `Urwa said, "Nowhere except in Medina the prayer used to be offered (in those days)." He further said, "The Prophet (ﷺ) used to offer the `Isha' prayer in the period between the disappearance of the twilight and the end of the first third of the night}}
\hadithdefcmd{bukhari}{571}{حَدَّثَنَا مَحْمُودٌ، قَالَ أَخْبَرَنَا عَبْدُ الرَّزَّاقِ، قَالَ أَخْبَرَنِي ابْنُ جُرَيْجٍ، قَالَ أَخْبَرَنِي نَافِعٌ، قَالَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم شُغِلَ عَنْهَا لَيْلَةً، فَأَخَّرَهَا حَتَّى رَقَدْنَا فِي الْمَسْجِدِ، ثُمَّ اسْتَيْقَظْنَا ثُمَّ رَقَدْنَا ثُمَّ اسْتَيْقَظْنَا، ثُمَّ خَرَجَ عَلَيْنَا النَّبِيُّ صلى الله عليه وسلم ثُمَّ قَالَ ‏"‏ لَيْسَ أَحَدٌ مِنْ أَهْلِ الأَرْضِ يَنْتَظِرُ الصَّلاَةَ غَيْرُكُمْ ‏"‏‏.‏ وَكَانَ ابْنُ عُمَرَ لاَ يُبَالِي أَقَدَّمَهَا أَمْ أَخَّرَهَا إِذَا كَانَ لاَ يَخْشَى أَنْ يَغْلِبَهُ النَّوْمُ عَنْ وَقْتِهَا، وَكَانَ يَرْقُدُ قَبْلَهَا‏.‏ قَالَ ابْنُ جُرَيْجٍ قُلْتُ لِعَطَاءٍ وَقَالَ سَمِعْتُ ابْنَ عَبَّاسٍ، يَقُولُ أَعْتَمَ رَسُولُ اللَّهِ صلى الله عليه وسلم لَيْلَةً بِالْعِشَاءِ حَتَّى رَقَدَ النَّاسُ وَاسْتَيْقَظُوا، وَرَقَدُوا وَاسْتَيْقَظُوا، فَقَامَ عُمَرُ بْنُ الْخَطَّابِ فَقَالَ الصَّلاَةَ‏.‏ قَالَ عَطَاءٌ قَالَ ابْنُ عَبَّاسٍ فَخَرَجَ نَبِيُّ اللَّهِ صلى الله عليه وسلم كَأَنِّي أَنْظُرُ إِلَيْهِ الآنَ، يَقْطُرُ رَأْسُهُ مَاءً، وَاضِعًا يَدَهُ عَلَى رَأْسِهِ فَقَالَ ‏"‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ أَنْ يُصَلُّوهَا هَكَذَا ‏"‏‏.‏ فَاسْتَثْبَتُّ عَطَاءً كَيْفَ وَضَعَ النَّبِيُّ صلى الله عليه وسلم عَلَى رَأْسِهِ يَدَهُ كَمَا أَنْبَأَهُ ابْنُ عَبَّاسٍ، فَبَدَّدَ لِي عَطَاءٌ بَيْنَ أَصَابِعِهِ شَيْئًا مِنْ تَبْدِيدٍ، ثُمَّ وَضَعَ أَطْرَافَ أَصَابِعِهِ عَلَى قَرْنِ الرَّأْسِ ثُمَّ ضَمَّهَا، يُمِرُّهَا كَذَلِكَ عَلَى الرَّأْسِ حَتَّى مَسَّتْ إِبْهَامُهُ طَرَفَ الأُذُنِ مِمَّا يَلِي الْوَجْهَ عَلَى الصُّدْغِ، وَنَاحِيَةِ اللِّحْيَةِ، لاَ يُقَصِّرُ وَلاَ يَبْطُشُ إِلاَّ كَذَلِكَ وَقَالَ ‏"‏ لَوْلاَ أَنْ أَشُقَّ عَلَى أُمَّتِي لأَمَرْتُهُمْ أَنْ يُصَلُّوا هَكَذَا ‏"‏‏.‏\hadithno{571}\hadithtrans{Narrated Ibn Juraij from Nafi`:`Abdullah bin `Umar said, "Once Allah's Messenger (ﷺ) was busy (at the time of the `Isha'), so the prayer was delayed so much so that we slept and woke up and slept and woke up again. The Prophet (ﷺ) came out and said, 'None amongst the dwellers of the earth but you have been waiting for the prayer." Ibn `Umar did not find any harm in praying it earlier or in delaying it unless he was afraid that sleep might overwhelm him and he might miss the prayer, and sometimes he used to sleep before the `Isha' prayer. Ibn Juraij said, "I said to `Ata', 'I heard Ibn `Abbas saying: Once Allah's Messenger (ﷺ) delayed the `Isha' prayer to such an extent that the people slept and got up and slept again and got up again. Then `Umar bin Al-Khattab, stood up and reminded the Prophet (ﷺ) of the prayer.' `Ata' said, 'Ibn `Abbas said: The Prophet came out as if I was looking at him at this time, and water was trickling from his head and he was putting his hand on his head and then said, 'Hadn't I thought it hard for my followers, I would have ordered them to pray (`Isha' prayer) at this time.' I asked `Ata' for further information, how the Prophet had kept his hand on his head as he was told by Ibn `Abbas. `Ata' separated his fingers slightly and put their tips on the side of the head, brought the fingers downwards approximating them till the thumb touched the lobe of the ear at the side of the temple and the beard on the face. He neither slowed nor hurried in this action but he acted like that. The Prophet (ﷺ) said: "Hadn't I thought it hard for my followers I would have ordered them to pray at this time}}
\hadithdefcmd{bukhari}{572}{حَدَّثَنَا عَبْدُ الرَّحِيمِ الْمُحَارِبِيُّ، قَالَ حَدَّثَنَا زَائِدَةُ، عَنْ حُمَيْدٍ الطَّوِيلِ، عَنْ أَنَسٍ، قَالَ أَخَّرَ النَّبِيُّ صلى الله عليه وسلم صَلاَةَ الْعِشَاءِ إِلَى نِصْفِ اللَّيْلِ، ثُمَّ صَلَّى ثُمَّ قَالَ ‏ "‏ قَدْ صَلَّى النَّاسُ وَنَامُوا، أَمَا إِنَّكُمْ فِي صَلاَةٍ مَا انْتَظَرْتُمُوهَا ‏"‏‏.‏ وَزَادَ ابْنُ أَبِي مَرْيَمَ أَخْبَرَنَا يَحْيَى بْنُ أَيُّوبَ حَدَّثَنِي حُمَيْدٌ سَمِعَ أَنَسًا كَأَنِّي أَنْظُرُ إِلَى وَبِيصِ خَاتَمِهِ لَيْلَتَئِذٍ‏.‏\hadithno{572}\hadithtrans{Narrated Anas:The Prophet (ﷺ) delayed the `Isha' prayer till midnight and then he offered the prayer and said, "The people prayed and slept but you have been in prayer as long as you have been waiting for it (the prayer)." Anas added: As if I am looking now at the glitter of the ring of the Prophet (ﷺ) on that night}}
\hadithdefcmd{bukhari}{573}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ إِسْمَاعِيلَ، حَدَّثَنَا قَيْسٌ، قَالَ لِي جَرِيرُ بْنُ عَبْدِ اللَّهِ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم إِذْ نَظَرَ إِلَى الْقَمَرِ لَيْلَةَ الْبَدْرِ فَقَالَ ‏"‏ أَمَا إِنَّكُمْ سَتَرَوْنَ رَبَّكُمْ كَمَا تَرَوْنَ هَذَا، لاَ تُضَامُّونَ ـ أَوْ لاَ تُضَاهُونَ ـ فِي رُؤْيَتِهِ، فَإِنِ اسْتَطَعْتُمْ أَنْ لاَ تُغْلَبُوا عَلَى صَلاَةٍ قَبْلَ طُلُوعِ الشَّمْسِ، وَقَبْلَ غُرُوبِهَا فَافْعَلُوا ‏"‏‏.‏ ثُمَّ قَالَ ‏"‏ فَسَبِّحْ بِحَمْدِ رَبِّكَ قَبْلَ طُلُوعِ الشَّمْسِ وَقَبْلَ غُرُوبِهَا ‏"‏‏.‏\hadithno{573}\hadithtrans{Narrated Jarir bin `Abdullah:We were with the Prophet (ﷺ) on a full moon night. He looked at the moon and said, "You will certainly see your Lord as you see this moon, and there will be no trouble in seeing Him. So if you can avoid missing (through sleep, business, etc.) a prayer before the rising of the sun (Fajr) and before its setting (`Asr) you must do so. He (the Prophet (ﷺ) ) then recited the following verse: And celebrate the praises Of Your Lord before The rising of the sun And before (its) setting}}
\hadithdefcmd{bukhari}{574}{حَدَّثَنَا هُدْبَةُ بْنُ خَالِدٍ، قَالَ حَدَّثَنَا هَمَّامٌ، حَدَّثَنِي أَبُو جَمْرَةَ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَلَّى الْبَرْدَيْنِ دَخَلَ الْجَنَّةَ ‏"‏‏.‏ وَقَالَ ابْنُ رَجَاءٍ حَدَّثَنَا هَمَّامٌ عَنْ أَبِي جَمْرَةَ أَنَّ أَبَا بَكْرِ بْنَ عَبْدِ اللَّهِ بْنِ قَيْسٍ أَخْبَرَهُ بِهَذَا‏.‏ حَدَّثَنَا إِسْحَاقُ، عَنْ حَبَّانَ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا أَبُو جَمْرَةَ، عَنْ أَبِي بَكْرِ بْنِ عَبْدِ اللَّهِ، عَنْ أَبِيهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَهُ‏.‏\hadithno{574}\hadithtrans{Narrated Abu Bakr bin Abi Musa:My father said, "Allah's Messenger (ﷺ) said, 'Whoever prays the two cool prayers (`Asr and Fajr) will go to Paradise}}
\hadithdefcmd{bukhari}{575}{حَدَّثَنَا عَمْرُو بْنُ عَاصِمٍ، قَالَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، أَنَّ زَيْدَ بْنَ ثَابِتٍ، حَدَّثَهُ أَنَّهُمْ، تَسَحَّرُوا مَعَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ قَامُوا إِلَى الصَّلاَةِ‏.‏ قُلْتُ كَمْ بَيْنَهُمَا قَالَ قَدْرُ خَمْسِينَ أَوْ سِتِّينَ ـ يَعْنِي آيَةً ـ ح‏.‏\hadithno{575}\hadithtrans{Narrated Anas:Zaid bin Thabit said, "We took the "Suhur" (the meal taken before dawn while fasting is observed) with the Prophet (ﷺ) and then stood up for the (morning) prayer." I asked him how long the interval between the two (Suhur and prayer) was. He replied, 'The interval between the two was just sufficient to recite fifty to sixty 'Ayat}}
\hadithdefcmd{bukhari}{576}{حَدَّثَنَا حَسَنُ بْنُ صَبَّاحٍ، سَمِعَ رَوْحًا، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ نَبِيَّ اللَّهِ صلى الله عليه وسلم وَزَيْدَ بْنَ ثَابِتٍ تَسَحَّرَا، فَلَمَّا فَرَغَا مِنْ سَحُورِهِمَا قَامَ نَبِيُّ اللَّهِ صلى الله عليه وسلم إِلَى الصَّلاَةِ فَصَلَّى‏.‏ قُلْنَا لأَنَسٍ كَمْ كَانَ بَيْنَ فَرَاغِهِمَا مِنْ سَحُورِهِمَا وَدُخُولِهِمَا فِي الصَّلاَةِ قَالَ قَدْرُ مَا يَقْرَأُ الرَّجُلُ خَمْسِينَ آيَةً‏.‏\hadithno{576}\hadithtrans{Narrated Qatada:Anas bin Malik said, "The Prophet (ﷺ) and Zaid bin Thabit took the 'Suhur' together and after finishing the meal, the Prophet (ﷺ) stood up and prayed (Fajr prayer)." I asked Anas, "How long was the interval between finishing their 'Suhur' and starting the prayer?" He replied, "The interval between the two was just sufficient to recite fifty 'Ayat." (Verses of the Qur'an)}}
\hadithdefcmd{bukhari}{577}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَبِي أُوَيْسٍ، عَنْ أَخِيهِ، عَنْ سُلَيْمَانَ، عَنْ أَبِي حَازِمٍ، أَنَّهُ سَمِعَ سَهْلَ بْنَ سَعْدٍ، يَقُولُ كُنْتُ أَتَسَحَّرُ فِي أَهْلِي ثُمَّ يَكُونُ سُرْعَةٌ بِي أَنْ أُدْرِكَ صَلاَةَ الْفَجْرِ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم‏.‏\hadithno{577}\hadithtrans{Narrated Sahl bin Sa`d:I used to take the "Suhur" meal with my family and hasten so as to catch the Fajr (morning prayer) with Allah's Messenger (ﷺ)}}
\hadithdefcmd{bukhari}{578}{حَدَّثَنَا يَحْيَى بْنُ بُكَيْرٍ، قَالَ أَخْبَرَنَا اللَّيْثُ، عَنْ عُقَيْلٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، أَخْبَرَتْهُ قَالَتْ، كُنَّ نِسَاءُ الْمُؤْمِنَاتِ يَشْهَدْنَ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم صَلاَةَ الْفَجْرِ مُتَلَفِّعَاتٍ بِمُرُوطِهِنَّ، ثُمَّ يَنْقَلِبْنَ إِلَى بُيُوتِهِنَّ حِينَ يَقْضِينَ الصَّلاَةَ، لاَ يَعْرِفُهُنَّ أَحَدٌ مِنَ الْغَلَسِ‏.‏\hadithno{578}\hadithtrans{Narrated `Aisha:The believing women covered with their veiling sheets used to attend the Fajr prayer with Allah's Apostle, and after finishing the prayer they would return to their home and nobody could recognize them because of darkness}}
\hadithdefcmd{bukhari}{579}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ زَيْدِ بْنِ أَسْلَمَ، عَنْ عَطَاءِ بْنِ يَسَارٍ، وَعَنْ بُسْرِ بْنِ سَعِيدٍ، وَعَنِ الأَعْرَجِ، يُحَدِّثُونَهُ عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ مِنَ الصُّبْحِ رَكْعَةً قَبْلَ أَنْ تَطْلُعَ الشَّمْسُ فَقَدْ أَدْرَكَ الصُّبْحَ، وَمَنْ أَدْرَكَ رَكْعَةً مِنَ الْعَصْرِ قَبْلَ أَنْ تَغْرُبَ الشَّمْسُ فَقَدْ أَدْرَكَ الْعَصْرَ ‏"‏‏.‏\hadithno{579}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever could get one rak`a (of the Fajr prayer) before sunrise, he has got the (morning) prayer and whoever could get one rak`a of the `Asr prayer before sunset, he has got the (`Asr) prayer}}
\hadithdefcmd{bukhari}{580}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنِ ابْنِ شِهَابٍ، عَنْ أَبِي سَلَمَةَ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَدْرَكَ رَكْعَةً مِنَ الصَّلاَةِ فَقَدْ أَدْرَكَ الصَّلاَةَ ‏"‏‏.‏\hadithno{580}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) said, "Whoever could get one rak`a of a prayer, (in its proper time) he has got the prayer}}
\hadithdefcmd{bukhari}{581}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ قَتَادَةَ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ شَهِدَ عِنْدِي رِجَالٌ مَرْضِيُّونَ وَأَرْضَاهُمْ عِنْدِي عُمَرُ أَنَّ النَّبِيَّ صلى الله عليه وسلم نَهَى عَنِ الصَّلاَةِ بَعْدَ الصُّبْحِ حَتَّى تَشْرُقَ الشَّمْسُ، وَبَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ‏.‏ حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، عَنْ قَتَادَةَ، سَمِعْتُ أَبَا الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَنِي نَاسٌ، بِهَذَا‏.‏\hadithno{581}\hadithtrans{Narrated `Umar:"The Prophet (ﷺ) forbade praying after the Fajr prayer till the sun rises and after the `Asr prayer till the sun sets." Narrated Ibn `Abbas: Some people told me the same narration (as above)}}
\hadithdefcmd{bukhari}{583}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، عَنْ هِشَامٍ، قَالَ أَخْبَرَنِي أَبِي قَالَ، أَخْبَرَنِي ابْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَحَرَّوْا بِصَلاَتِكُمْ طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا ‏"‏‏.‏ وَقَالَ حَدَّثَنِي ابْنُ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِذَا طَلَعَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَرْتَفِعَ، وَإِذَا غَابَ حَاجِبُ الشَّمْسِ فَأَخِّرُوا الصَّلاَةَ حَتَّى تَغِيبَ ‏"‏‏.‏ تَابَعَهُ عَبْدَةُ‏.‏\hadithno{583}\hadithtrans{Narrated Hisham's father:Ibn `Umar said, "Allah's Messenger (ﷺ) said, 'Do not pray at the time of sunrise and at the time of sunset.' " Ibn `Umar said, "Allah's Messenger (ﷺ) said, 'If the edge of the sun appears (above the horizon) delay the prayer till it becomes high, and if the edge of the sun disappears, delay the prayer till it sets (disappears completely)}}
\hadithdefcmd{bukhari}{584}{حَدَّثَنَا عُبَيْدُ بْنُ إِسْمَاعِيلَ، عَنْ أَبِي أُسَامَةَ، عَنْ عُبَيْدِ اللَّهِ، عَنْ خُبَيْبِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْ بَيْعَتَيْنِ وَعَنْ لِبْسَتَيْنِ وَعَنْ صَلاَتَيْنِ نَهَى عَنِ الصَّلاَةِ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ، وَبَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ، وَعَنِ اشْتِمَالِ الصَّمَّاءِ وَعَنْ الاِحْتِبَاءِ فِي ثَوْبٍ وَاحِدٍ يُفْضِي بِفَرْجِهِ إِلَى السَّمَاءِ، وَعَنِ الْمُنَابَذَةِ وَالْمُلاَمَسَةِ‏.‏\hadithno{584}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade two kinds of sales, two kinds of dresses, and two prayers. He forbade offering prayers after the Fajr prayer till the rising of the sun and after the `Asr prayer till its setting. He also forbade "Ishtimal-Assama [??] " and "al-Ihtiba" in one garment in such a way that one's private parts are exposed towards the sky. He also forbade the sales called "Munabadha" and "Mulamasa." (See Hadith No. 354 and 355 Vol)}}
\hadithdefcmd{bukhari}{585}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يُوسُفَ، قَالَ أَخْبَرَنَا مَالِكٌ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَتَحَرَّى أَحَدُكُمْ فَيُصَلِّي عِنْدَ طُلُوعِ الشَّمْسِ وَلاَ عِنْدَ غُرُوبِهَا ‏"‏‏.‏\hadithno{585}\hadithtrans{Narrated Ibn `Umar:Allah's Messenger (ﷺ) said, "None of you should try to pray at sunrise or sunset}}
\hadithdefcmd{bukhari}{586}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا إِبْرَاهِيمُ بْنُ سَعْدٍ، عَنْ صَالِحٍ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عَطَاءُ بْنُ يَزِيدَ الْجُنْدَعِيُّ، أَنَّهُ سَمِعَ أَبَا سَعِيدٍ الْخُدْرِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ لاَ صَلاَةَ بَعْدَ الصُّبْحِ حَتَّى تَرْتَفِعَ الشَّمْسُ، وَلاَ صَلاَةَ بَعْدَ الْعَصْرِ حَتَّى تَغِيبَ الشَّمْسُ ‏"‏‏.‏\hadithno{586}\hadithtrans{Narrated Abu Sa`id Al-Khudri:I heard Allah's Messenger (ﷺ) saying, "There is no prayer after the morning prayer till the sun rises, and there is no prayer after the `Asr prayer till the sun sets}}
\hadithdefcmd{bukhari}{587}{حَدَّثَنَا مُحَمَّدُ بْنُ أَبَانَ، قَالَ حَدَّثَنَا غُنْدَرٌ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي التَّيَّاحِ، قَالَ سَمِعْتُ حُمْرَانَ بْنَ أَبَانَ، يُحَدِّثُ عَنْ مُعَاوِيَةَ، قَالَ إِنَّكُمْ لَتُصَلُّونَ صَلاَةً، لَقَدْ صَحِبْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم فَمَا رَأَيْنَاهُ يُصَلِّيهَا، وَلَقَدْ نَهَى عَنْهُمَا، يَعْنِي الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ‏.‏\hadithno{587}\hadithtrans{Narrated Muawiya:You offer a prayer which I did not see being offered by Allah's Messenger (ﷺ) when we were in his company and he certainly had forbidden it (i.e. two rak`at after the `Asr prayer)}}
\hadithdefcmd{bukhari}{588}{حَدَّثَنَا مُحَمَّدُ بْنُ سَلاَمٍ، قَالَ حَدَّثَنَا عَبْدَةُ، عَنْ عُبَيْدِ اللَّهِ، عَنْ خُبَيْبٍ، عَنْ حَفْصِ بْنِ عَاصِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ صَلاَتَيْنِ بَعْدَ الْفَجْرِ حَتَّى تَطْلُعَ الشَّمْسُ، وَبَعْدَ الْعَصْرِ حَتَّى تَغْرُبَ الشَّمْسُ‏.‏\hadithno{588}\hadithtrans{Narrated Abu Huraira:Allah's Messenger (ﷺ) forbade the offering of two prayers: -1. after the morning prayer till the sunrises. -2. after the `Asr prayer till the sun sets}}
\hadithdefcmd{bukhari}{589}{حَدَّثَنَا أَبُو النُّعْمَانِ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أُصَلِّي كَمَا رَأَيْتُ أَصْحَابِي يُصَلُّونَ، لاَ أَنْهَى أَحَدًا يُصَلِّي بِلَيْلٍ وَلاَ نَهَارٍ مَا شَاءَ، غَيْرَ أَنْ لاَ تَحَرَّوْا طُلُوعَ الشَّمْسِ وَلاَ غُرُوبَهَا‏.‏\hadithno{589}\hadithtrans{Narrated Ibn `Umar:I pray as I saw my companions praying. I do not forbid praying at any time during the day or night except at sunset and sunrise}}
\hadithdefcmd{bukhari}{590}{حَدَّثَنَا أَبُو نُعَيْمٍ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ أَيْمَنَ، قَالَ حَدَّثَنِي أَبِي أَنَّهُ، سَمِعَ عَائِشَةَ، قَالَتْ وَالَّذِي ذَهَبَ بِهِ مَا تَرَكَهُمَا حَتَّى لَقِيَ اللَّهَ، وَمَا لَقِيَ اللَّهَ تَعَالَى حَتَّى ثَقُلَ عَنِ الصَّلاَةِ، وَكَانَ يُصَلِّي كَثِيرًا مِنْ صَلاَتِهِ قَاعِدًا ـ تَعْنِي الرَّكْعَتَيْنِ بَعْدَ الْعَصْرِ ـ وَكَانَ النَّبِيُّ صلى الله عليه وسلم يُصَلِّيهِمَا، وَلاَ يُصَلِّيهِمَا فِي الْمَسْجِدِ مَخَافَةَ أَنْ يُثَقِّلَ عَلَى أُمَّتِهِ، وَكَانَ يُحِبُّ مَا يُخَفَّفُ عَنْهُمْ‏.‏\hadithno{590}\hadithtrans{Narrated `Aisha:By Allah, Who took away the Prophet. The Prophet (ﷺ) never missed them (two rak`at) after the `Asr prayer till he met Allah and he did not meet Allah till it became heavy for him to pray while standing so he used to offer most of the prayers while sitting. (She meant the two rak`at after `Asr) He used to pray them in the house and never prayed them in the mosque lest it might be hard for his followers and he loved what was easy for them}}
\hadithdefcmd{bukhari}{591}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا هِشَامٌ، قَالَ أَخْبَرَنِي أَبِي قَالَتْ، عَائِشَةُ ابْنَ أُخْتِي مَا تَرَكَ النَّبِيُّ صلى الله عليه وسلم السَّجْدَتَيْنِ بَعْدَ الْعَصْرِ عِنْدِي قَطُّ‏.‏\hadithno{591}\hadithtrans{Narrated Hisham's father:`Aisha (addressing me) said, "O son of my sister! The Prophet (ﷺ) never missed two prostrations (i.e. rak`at) after the `Asr prayer in my house}}
\hadithdefcmd{bukhari}{592}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، قَالَ حَدَّثَنَا عَبْدُ الْوَاحِدِ، قَالَ حَدَّثَنَا الشَّيْبَانِيُّ، قَالَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ الأَسْوَدِ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ رَكْعَتَانِ لَمْ يَكُنْ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدَعُهُمَا سِرًّا وَلاَ عَلاَنِيَةً رَكْعَتَانِ قَبْلَ صَلاَةِ الصُّبْحِ، وَرَكْعَتَانِ بَعْدَ الْعَصْرِ‏.‏\hadithno{592}\hadithtrans{Narrated `Aisha:Allah's Messenger (ﷺ) never missed two rak`at before the Fajr prayer and after the `Asr prayer openly and secretly}}
\hadithdefcmd{bukhari}{593}{حَدَّثَنَا مُحَمَّدُ بْنُ عَرْعَرَةَ، قَالَ حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي إِسْحَاقَ، قَالَ رَأَيْتُ الأَسْوَدَ وَمَسْرُوقًا شَهِدَا عَلَى عَائِشَةَ قَالَتْ مَا كَانَ النَّبِيُّ صلى الله عليه وسلم يَأْتِينِي فِي يَوْمٍ بَعْدَ الْعَصْرِ إِلاَّ صَلَّى رَكْعَتَيْنِ‏.‏\hadithno{593}\hadithtrans{Narrated `Aisha:Whenever the Prophet (ﷺ) come to me after the `Asr prayer, he always prayed two rak`at}}
\hadithdefcmd{bukhari}{594}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى ـ هُوَ ابْنُ أَبِي كَثِيرٍ ـ عَنْ أَبِي قِلاَبَةَ، أَنَّ أَبَا الْمَلِيحِ، حَدَّثَهُ قَالَ كُنَّا مَعَ بُرَيْدَةَ فِي يَوْمٍ ذِي غَيْمٍ فَقَالَ بَكِّرُوا بِالصَّلاَةِ فَإِنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ تَرَكَ صَلاَةَ الْعَصْرِ حَبِطَ عَمَلُهُ ‏"‏‏.‏\hadithno{594}\hadithtrans{Narrated Ibn Abu Malih [??]:I was with Buraida on a cloudy day and he said, "Offer the `Asr prayer earlier as the Prophet (ﷺ) said, 'Whoever leaves the `Asr prayer will have all his (good) deeds annulled." (See Hadith No. 527 and)}}
\hadithdefcmd{bukhari}{595}{حَدَّثَنَا عِمْرَانُ بْنُ مَيْسَرَةَ، قَالَ حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، قَالَ حَدَّثَنَا حُصَيْنٌ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي قَتَادَةَ، عَنْ أَبِيهِ، قَالَ سِرْنَا مَعَ النَّبِيِّ صلى الله عليه وسلم لَيْلَةً فَقَالَ بَعْضُ الْقَوْمِ لَوْ عَرَّسْتَ بِنَا يَا رَسُولَ اللَّهِ‏.‏ قَالَ ‏"‏ أَخَافُ أَنْ تَنَامُوا عَنِ الصَّلاَةِ ‏"‏‏.‏ قَالَ بِلاَلٌ أَنَا أُوقِظُكُمْ‏.‏ فَاضْطَجَعُوا وَأَسْنَدَ بِلاَلٌ ظَهْرَهُ إِلَى رَاحِلَتِهِ، فَغَلَبَتْهُ عَيْنَاهُ فَنَامَ، فَاسْتَيْقَظَ النَّبِيُّ صلى الله عليه وسلم وَقَدْ طَلَعَ حَاجِبُ الشَّمْسِ فَقَالَ ‏"‏ يَا بِلاَلُ أَيْنَ مَا قُلْتَ ‏"‏‏.‏ قَالَ مَا أُلْقِيَتْ عَلَىَّ نَوْمَةٌ مِثْلُهَا قَطُّ‏.‏ قَالَ ‏"‏ إِنَّ اللَّهَ قَبَضَ أَرْوَاحَكُمْ حِينَ شَاءَ، وَرَدَّهَا عَلَيْكُمْ حِينَ شَاءَ، يَا بِلاَلُ قُمْ فَأَذِّنْ بِالنَّاسِ بِالصَّلاَةِ ‏"‏‏.‏ فَتَوَضَّأَ فَلَمَّا ارْتَفَعَتِ الشَّمْسُ وَابْيَاضَّتْ قَامَ فَصَلَّى‏.‏\hadithno{595}\hadithtrans{Narrated `Abdullah bin Abi Qatada:My father said, "One night we were traveling with the Prophet (ﷺ) and some people said, 'We wish that Allah's Messenger (ﷺ) would take a rest along with us during the last hours of the night.' He said, 'I am afraid that you will sleep and miss the (Fajr) prayer.' Bilal said, 'I will make you get up.' So all slept and Bilal rested his back against his Rahila and he too was overwhelmed (by sleep) and slept. The Prophet (ﷺ) got up when the edge of the sun had risen and said, 'O Bilal! What about your statement?' He replied, 'I have never slept such a sleep.' The Prophet (ﷺ) said, 'Allah captured your souls when He wished, and released them when He wished. O Bilal! Get up and pronounce the Adhan for the prayer.' The Prophet (ﷺ) performed ablution and when the sun came up and became bright, he stood up and prayed}}
\hadithdefcmd{bukhari}{596}{حَدَّثَنَا مُعَاذُ بْنُ فَضَالَةَ، قَالَ حَدَّثَنَا هِشَامٌ، عَنْ يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ عُمَرَ بْنَ الْخَطَّابِ، جَاءَ يَوْمَ الْخَنْدَقِ بَعْدَ مَا غَرَبَتِ الشَّمْسُ، فَجَعَلَ يَسُبُّ كُفَّارَ قُرَيْشٍ قَالَ يَا رَسُولَ اللَّهِ مَا كِدْتُ أُصَلِّي الْعَصْرَ حَتَّى كَادَتِ الشَّمْسُ تَغْرُبُ‏.‏ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ وَاللَّهِ مَا صَلَّيْتُهَا ‏"‏‏.‏ فَقُمْنَا إِلَى بُطْحَانَ، فَتَوَضَّأَ لِلصَّلاَةِ، وَتَوَضَّأْنَا لَهَا فَصَلَّى الْعَصْرَ بَعْدَ مَا غَرَبَتِ الشَّمْسُ، ثُمَّ صَلَّى بَعْدَهَا الْمَغْرِبَ‏.‏\hadithno{596}\hadithtrans{Narrated Jabir bin `Abdullah:On the day of Al-Khandaq (the battle of trench.) `Umar bin Al-Khattab came cursing the disbelievers of Quraish after the sun had set and said, "O Allah's Messenger (ﷺ) I could not offer the `Asr prayer till the sun had set." The Prophet (ﷺ) said, "By Allah! I, too, have not prayed." So we turned towards Buthan, and the Prophet (ﷺ) performed ablution and we too performed ablution and offered the `Asr prayer after the sun had set, and then he offered the Maghrib prayer}}
\hadithdefcmd{bukhari}{597}{حَدَّثَنَا أَبُو نُعَيْمٍ، وَمُوسَى بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا هَمَّامٌ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ مَنْ نَسِيَ صَلاَةً فَلْيُصَلِّ إِذَا ذَكَرَهَا، لاَ كَفَّارَةَ لَهَا إِلاَّ ذَلِكَ ‏"‏‏.‏ ‏\{‏وَأَقِمِ الصَّلاَةَ لِذِكْرِي‏\}‏ قَالَ مُوسَى قَالَ هَمَّامٌ سَمِعْتُهُ يَقُولُ بَعْدُ ‏\{‏وَأَقِمِ الصَّلاَةَ لِذِكْرِي‏\}‏‏.‏وَقَالَ حَبَّانُ حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، حَدَّثَنَا أَنَسٌ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ‏.‏\hadithno{597}\hadithtrans{Narrated Anas:The Prophet (ﷺ) said, "If anyone forgets a prayer he should pray that prayer when he remembers it. There is no expiation except to pray the same." Then he recited: "Establish prayer for My (i.e. Allah's) remembrance}}
\hadithdefcmd{bukhari}{598}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، عَنْ هِشَامٍ، قَالَ حَدَّثَنَا يَحْيَى ـ هُوَ ابْنُ أَبِي كَثِيرٍ ـ عَنْ أَبِي سَلَمَةَ، عَنْ جَابِرٍ، قَالَ جَعَلَ عُمَرُ يَوْمَ الْخَنْدَقِ يَسُبُّ كُفَّارَهُمْ وَقَالَ مَا كِدْتُ أُصَلِّي الْعَصْرَ حَتَّى غَرَبَتْ‏.‏ قَالَ فَنَزَلْنَا بُطْحَانَ، فَصَلَّى بَعْدَ مَا غَرَبَتِ الشَّمْسُ، ثُمَّ صَلَّى الْمَغْرِبَ‏.‏\hadithno{598}\hadithtrans{Narrated Jabir:`Umar came cursing the disbelievers (of Quraish) on the day of Al-Khandaq (the battle of Trench) and said, "I could not offer the `Asr prayer till the sun had set. Then we went to Buthan and he offered the (`Asr) prayer after sunset and then he offered the Maghrib prayer}}
\hadithdefcmd{bukhari}{599}{حَدَّثَنَا مُسَدَّدٌ، قَالَ حَدَّثَنَا يَحْيَى، قَالَ حَدَّثَنَا عَوْفٌ، قَالَ حَدَّثَنَا أَبُو الْمِنْهَالِ، قَالَ انْطَلَقْتُ مَعَ أَبِي إِلَى أَبِي بَرْزَةَ الأَسْلَمِيِّ فَقَالَ لَهُ أَبِي حَدِّثْنَا كَيْفَ، كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يُصَلِّي الْمَكْتُوبَةَ قَالَ كَانَ يُصَلِّي الْهَجِيرَ وَهْىَ الَّتِي تَدْعُونَهَا الأُولَى حِينَ تَدْحَضُ الشَّمْسُ، وَيُصَلِّي الْعَصْرَ، ثُمَّ يَرْجِعُ أَحَدُنَا إِلَى أَهْلِهِ فِي أَقْصَى الْمَدِينَةِ وَالشَّمْسُ حَيَّةٌ، وَنَسِيتُ مَا قَالَ فِي الْمَغْرِبِ‏.‏ قَالَ وَكَانَ يَسْتَحِبُّ أَنْ يُؤَخِّرَ الْعِشَاءَ‏.‏ قَالَ وَكَانَ يَكْرَهُ النَّوْمَ قَبْلَهَا وَالْحَدِيثَ بَعْدَهَا، وَكَانَ يَنْفَتِلُ مِنْ صَلاَةِ الْغَدَاةِ حِينَ يَعْرِفُ أَحَدُنَا جَلِيسَهُ، وَيَقْرَأُ مِنَ السِّتِّينَ إِلَى الْمِائَةِ‏.‏\hadithno{599}\hadithtrans{Narrated Abu-l-Minhal:My father and I went to Abi Barza Al-Aslami and my father said to him, "Tell us how Allah's Messenger (ﷺ) used to offer the compulsory congregational prayers." He said, "He used to pray the Zuhr prayer, which you call the first prayer, as the sun declined at noon, the `Asr at a time when one of US could go to his family at the farthest place in Medina while the sun was still hot. (The narrator forgot what Abu Barza had said about the Maghrib prayer), and the Prophet (ﷺ) preferred to pray the `Isha' late and disliked to sleep before it or talk after it. And he used to return after finishing the morning prayer at such a time when it was possible for one to recognize the person sitting by his side and he (the Prophet) used to recite 60 to 100 'Ayat' (verses) of the Qur'an in it}}
\hadithdefcmd{bukhari}{600}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الصَّبَّاحِ، قَالَ حَدَّثَنَا أَبُو عَلِيٍّ الْحَنَفِيُّ، حَدَّثَنَا قُرَّةُ بْنُ خَالِدٍ، قَالَ انْتَظَرْنَا الْحَسَنَ وَرَاثَ عَلَيْنَا حَتَّى قَرُبْنَا مِنْ وَقْتِ قِيَامِهِ، فَجَاءَ فَقَالَ دَعَانَا جِيرَانُنَا هَؤُلاَءِ‏.‏ ثُمَّ قَالَ قَالَ أَنَسٌ نَظَرْنَا النَّبِيَّ صلى الله عليه وسلم ذَاتَ لَيْلَةٍ حَتَّى كَانَ شَطْرُ اللَّيْلِ يَبْلُغُهُ، فَجَاءَ فَصَلَّى لَنَا، ثُمَّ خَطَبَنَا فَقَالَ ‏ "‏ أَلاَ إِنَّ النَّاسَ قَدْ صَلَّوْا ثُمَّ رَقَدُوا، وَإِنَّكُمْ لَمْ تَزَالُوا فِي صَلاَةٍ مَا انْتَظَرْتُمُ الصَّلاَةَ ‏"‏‏.‏ قَالَ الْحَسَنُ وَإِنَّ الْقَوْمَ لاَ يَزَالُونَ بِخَيْرٍ مَا انْتَظَرُوا الْخَيْرَ‏.‏ قَالَ قُرَّةُ هُوَ مِنْ حَدِيثِ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم‏.‏\hadithno{600}\hadithtrans{Narrated Qurra bin Khalid:Once he waited for Al-Hasan and he did not show up till it was about the usual time for him to start his speech; then he came and apologized saying, "Our neighbors invited us." Then he added, "Narrated Anas, 'Once we waited for the Prophet (ﷺ) till it was midnight or about midnight. He came and led the prayer, and after finishing it, he addressed us and said, 'All the people prayed and then slept and you had been in prayer as long as you were waiting for it." Al-Hasan said, "The people are regarded as performing good deeds as long as they are waiting for doing good deeds." Al-Hasan's statement is a portion of Anas's [??] Hadith from the Prophet (ﷺ)}}
\hadithdefcmd{bukhari}{601}{حَدَّثَنَا أَبُو الْيَمَانِ، قَالَ أَخْبَرَنَا شُعَيْبٌ، عَنِ الزُّهْرِيِّ، قَالَ حَدَّثَنِي سَالِمُ بْنُ عَبْدِ اللَّهِ بْنِ عُمَرَ، وَأَبُو بَكْرِ بْنُ أَبِي حَثْمَةَ أَنَّ عَبْدَ اللَّهِ بْنَ عُمَرَ، قَالَ صَلَّى النَّبِيُّ صلى الله عليه وسلم صَلاَةَ الْعِشَاءِ فِي آخِرِ حَيَاتِهِ، فَلَمَّا سَلَّمَ قَامَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ ‏"‏ أَرَأَيْتَكُمْ لَيْلَتَكُمْ هَذِهِ فَإِنَّ رَأْسَ مِائَةٍ لاَ يَبْقَى مِمَّنْ هُوَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ أَحَدٌ ‏"‏‏.‏ فَوَهِلَ النَّاسُ فِي مَقَالَةِ رَسُولِ اللَّهِ ـ عَلَيْهِ السَّلاَمُ ـ إِلَى مَا يَتَحَدَّثُونَ مِنْ هَذِهِ الأَحَادِيثِ عَنْ مِائَةِ سَنَةٍ، وَإِنَّمَا قَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لاَ يَبْقَى مِمَّنْ هُوَ الْيَوْمَ عَلَى ظَهْرِ الأَرْضِ ‏"‏ يُرِيدُ بِذَلِكَ أَنَّهَا تَخْرِمُ ذَلِكَ الْقَرْنَ‏.‏\hadithno{601}\hadithtrans{Narrated `Abdullah bin `Umar:The Prophet (ﷺ) prayed one of the `Isha' prayer in his last days and after finishing it with Taslim, he stood up and said, "Do you realize (the importance of) this night? Nobody present on the surface of the earth tonight would be living after the completion of one hundred years from this night." The people made a mistake in grasping the meaning of this statement of Allah's Messenger (ﷺ) and they indulged in those things which are said about these narrators (i.e. some said that the Day of Resurrection will be established after 100 years etc.) But the Prophet (ﷺ) said, "Nobody present on the surface of earth tonight would be living after the completion of 100 years from this night"; he meant "When that century (people of that century) would pass away}}
\hadithdefcmd{bukhari}{602}{حَدَّثَنَا أَبُو النُّعْمَانِ، قَالَ حَدَّثَنَا مُعْتَمِرُ بْنُ سُلَيْمَانَ، قَالَ حَدَّثَنَا أَبِي، حَدَّثَنَا أَبُو عُثْمَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ، أَنَّ أَصْحَابَ الصُّفَّةِ، كَانُوا أُنَاسًا فُقَرَاءَ، وَأَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَ عِنْدَهُ طَعَامُ اثْنَيْنِ فَلْيَذْهَبْ بِثَالِثٍ، وَإِنْ أَرْبَعٌ فَخَامِسٌ أَوْ سَادِسٌ ‏"‏‏.‏ وَأَنَّ أَبَا بَكْرٍ جَاءَ بِثَلاَثَةٍ فَانْطَلَقَ النَّبِيُّ صلى الله عليه وسلم بِعَشَرَةٍ، قَالَ فَهْوَ أَنَا وَأَبِي وَأُمِّي، فَلاَ أَدْرِي قَالَ وَامْرَأَتِي وَخَادِمٌ بَيْنَنَا وَبَيْنَ بَيْتِ أَبِي بَكْرٍ‏.‏ وَإِنَّ أَبَا بَكْرٍ تَعَشَّى عِنْدَ النَّبِيِّ صلى الله عليه وسلم ثُمَّ لَبِثَ حَيْثُ صُلِّيَتِ الْعِشَاءُ، ثُمَّ رَجَعَ فَلَبِثَ حَتَّى تَعَشَّى النَّبِيُّ صلى الله عليه وسلم فَجَاءَ بَعْدَ مَا مَضَى مِنَ اللَّيْلِ مَا شَاءَ اللَّهُ، قَالَتْ لَهُ امْرَأَتُهُ وَمَا حَبَسَكَ عَنْ أَضْيَافِكَ ـ أَوْ قَالَتْ ضَيْفِكَ ـ قَالَ أَوَمَا عَشَّيْتِيهِمْ قَالَتْ أَبَوْا حَتَّى تَجِيءَ، قَدْ عُرِضُوا فَأَبَوْا‏.‏ قَالَ فَذَهَبْتُ أَنَا فَاخْتَبَأْتُ فَقَالَ يَا غُنْثَرُ، فَجَدَّعَ وَسَبَّ، وَقَالَ كُلُوا لاَ هَنِيئًا‏.‏ فَقَالَ وَاللَّهِ لاَ أَطْعَمُهُ أَبَدًا، وَايْمُ اللَّهِ مَا كُنَّا نَأْخُذُ مِنْ لُقْمَةٍ إِلاَّ رَبَا مِنْ أَسْفَلِهَا أَكْثَرُ مِنْهَا‏.‏ قَالَ يَعْنِي حَتَّى شَبِعُوا وَصَارَتْ أَكْثَرَ مِمَّا كَانَتْ قَبْلَ ذَلِكَ، فَنَظَرَ إِلَيْهَا أَبُو بَكْرٍ فَإِذَا هِيَ كَمَا هِيَ أَوْ أَكْثَرُ مِنْهَا‏.‏ فَقَالَ لاِمْرَأَتِهِ يَا أُخْتَ بَنِي فِرَاسٍ مَا هَذَا قَالَتْ لاَ وَقُرَّةِ عَيْنِي لَهِيَ الآنَ أَكْثَرُ مِنْهَا قَبْلَ ذَلِكَ بِثَلاَثِ مَرَّاتٍ‏.‏ فَأَكَلَ مِنْهَا أَبُو بَكْرٍ وَقَالَ إِنَّمَا كَانَ ذَلِكَ مِنَ الشَّيْطَانِ ـ يَعْنِي يَمِينَهُ ـ ثُمَّ أَكَلَ مِنْهَا لُقْمَةً، ثُمَّ حَمَلَهَا إِلَى النَّبِيِّ صلى الله عليه وسلم فَأَصْبَحَتْ عِنْدَهُ، وَكَانَ بَيْنَنَا وَبَيْنَ قَوْمٍ عَقْدٌ، فَمَضَى الأَجَلُ، فَفَرَّقَنَا اثْنَا عَشَرَ رَجُلاً، مَعَ كُلِّ رَجُلٍ مِنْهُمْ أُنَاسٌ، اللَّهُ أَعْلَمُ كَمْ مَعَ كُلِّ رَجُلٍ فَأَكَلُوا مِنْهَا أَجْمَعُونَ، أَوْ كَمَا قَالَ‏.‏\hadithno{602}\hadithtrans{Narrated Abu `Uthman:`Abdur Rahman bin Abi Bakr said, "The Suffa Companions were poor people and the Prophet (ﷺ) said, 'Whoever has food for two persons should take a third one from them (Suffa companions). And whosoever has food for four persons he should take one or two from them' Abu Bakr took three men and the Prophet (ﷺ) took ten of them." `Abdur Rahman added, my father my mother and I were there (in the house). (The sub-narrator is in doubt whether `Abdur Rahman also said, 'My wife and our servant who was common for both my house and Abu Bakr's house). Abu Bakr took his supper with the Prophet (ﷺ) and remained there till the `Isha' prayer was offered. Abu Bakr went back and stayed with the Prophet (ﷺ) till the Prophet (ﷺ) took his meal and then Abu Bakr returned to his house after a long portion of the night had passed. Abu Bakr's wife said, 'What detained you from your guests (or guest)?' He said, 'Have you not served them yet?' She said, 'They refused to eat until you come. The food was served for them but they refused." `Abdur Rahman added, "I went away and hid myself (being afraid of Abu Bakr) and in the meantime he (Abu Bakr) called me, 'O Ghunthar (a harsh word)!' and also called me bad names and abused me and then said (to his family), 'Eat. No welcome for you.' Then (the supper was served). Abu Bakr took an oath that he would not eat that food. The narrator added: By Allah, whenever any one of us (myself and the guests of Suffa companions) took anything from the food, it increased from underneath. We all ate to our fill and the food was more than it was before its serving. Abu Bakr looked at it (the food) and found it as it was before serving or even more than that. He addressed his wife (saying) 'O the sister of Bani Firas! What is this?' She said, 'O the pleasure of my eyes! The food is now three times more than it was before.' Abu Bakr ate from it, and said, 'That (oath) was from Satan' meaning his oath (not to eat). Then he again took a morsel (mouthful) from it and then took the rest of it to the Prophet. So that meal was with the Prophet. There was a treaty between us and some people, and when the period of that treaty had elapsed the Prophet (ﷺ) divided us into twelve (groups) (the Prophet's companions) each being headed by a man. Allah knows how many men were under the command of each (leader). So all of them (12 groups of men) ate of that meal}}
